/******************************************************************************
 * Copyright (c) 2010-2012, XIONLOGIC LIMITED                                 *
 * Copyright (c) 2010-2012, Niroshan Mahasinghe                               *
 * All rights reserved.                                                       *
 *                                                                            *
 * Redistribution and use in source and binary forms, with or without         *
 * modification, are permitted provided that the following conditions         *
 * are met:                                                                   *
 *                                                                            *
 *  o  Redistributions of source code must retain the above copyright         *
 *     notice, this list of conditions and the following disclaimer.          *
 *                                                                            *
 *  o  Redistributions in binary form must reproduce the above copyright      *
 *     notice, this list of conditions and the following disclaimer in        *
 *     the documentation and/or other materials provided with the             *
 *     distribution.                                                          *
 *                                                                            *
 *  o  Neither the name of XIONLOGIC LIMITED nor the names of its             *
 *     contributors may be used to endorse or promote products                *
 *     derived from this software without specific prior                      *
 *     written permission.                                                    *
 *                                                                            *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS        *
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED  *
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR *
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR          *
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,      *
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,        *
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR         *
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF     *
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING       *
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS         *
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.               *
 *****************************************************************************/

/*****************************************************************************
 *  Original Author(s):
 *      Niroshan Mahasinghe, nmahasinghe@xionlogic.com
 *****************************************************************************/
/** \file
 * \ingroup ModMiscIpDspFftR22Sdc
 * TFM stage-1 twiddle-factor ROM for 4096-point radix-2<sup>2</sup> SDF FFT
 * processors.
 * This file implements the TFM stage-1 twiddle-factor ROM for 4096-point
 * radix-2<sup>2</sup> SDF FFT processors.
 */

/***************************************************************************
 * Include files
 ***************************************************************************/
`include "system.vh"

/***************************************************************************
 * Modules
 ***************************************************************************/
/** \addtogroup ModMiscIpDspFftR22Sdc
 * @{
 */

/** TFM stage-1 twiddle-factor ROM for 4096-point radix-2<sup>2</sup> SDF FFT 
 * processors.
 * This module implements the stage-1 twiddle-factor ROM for 4096-point radix-2<sup>2</sup>
 * SDF FFT processors. It outputs the twiddle-factor, W<sup>nk</sup> for a given
 * \a nk one cycle later.
 *
 * \param[in]  clk      System clock.
 * \param[in]  rst_n    Active low asynchronous reset line.
 * \param[in]  addr     Twiddle-factor ROM address (i.e. \a nk) to read.
 * \param[in]  addr_vld Indicates that the read address is valid.
 * \param[out] tf_re    Twiddle-factor output (real part).
 * \param[out] tf_im    Twiddle-factor output (imaginary part).
 */
module fft_r22sdf_rom_4096_s1 (
    input  wire               clk,
    input  wire               rst_n,
    input  wire        [ 9:0] addr,
    input  wire               addr_vld,
    output wire signed [ 9:0] tf_re,
    output wire signed [ 9:0] tf_im
  );

  reg  [19:0] dout;

  assign tf_re = dout[19:10];
  assign tf_im = dout[ 9: 0];

  initial
    begin
     `ifndef USE_RESET
      dout = 20'd0;
     `endif
    end

  always @ (posedge clk or negedge rst_n)
    begin
      if (!rst_n)
        begin
         `ifdef USE_RESET
          dout <= 20'd0;
         `endif
        end
      else if (addr_vld)
        begin
          case (addr)
            10'h000: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h001: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h002: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h003: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h004: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h005: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h006: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h007: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h008: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h009: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h00A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h00B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h00C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h00D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h00E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h00F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h010: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h011: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h012: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h013: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h014: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h015: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h016: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h017: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h018: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h019: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h01A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h01B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h01C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h01D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h01E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h01F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h020: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h021: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h022: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h023: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h024: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h025: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h026: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h027: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h028: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h029: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h02A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h02B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h02C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h02D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h02E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h02F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h030: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h031: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h032: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h033: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h034: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h035: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h036: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h037: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h038: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h039: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h03A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h03B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h03C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h03D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h03E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h03F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h040: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h041: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h042: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h043: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h044: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h045: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h046: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h047: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h048: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h049: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h04A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h04B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h04C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h04D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h04E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h04F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h050: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h051: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h052: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h053: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h054: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h055: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h056: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h057: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h058: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h059: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h05A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h05B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h05C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h05D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h05E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h05F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h060: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h061: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h062: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h063: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h064: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h065: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h066: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h067: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h068: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h069: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h06A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h06B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h06C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h06D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h06E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h06F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h070: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h071: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h072: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h073: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h074: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h075: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h076: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h077: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h078: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h079: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h07A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h07B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h07C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h07D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h07E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h07F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h080: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h081: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h082: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h083: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h084: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h085: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h086: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h087: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h088: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h089: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h08A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h08B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h08C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h08D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h08E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h08F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h090: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h091: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h092: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h093: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h094: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h095: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h096: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h097: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h098: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h099: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h09A: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h09B: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h09C: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h09D: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h09E: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h09F: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0A0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0A1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0A2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0A3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0A4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0A5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0A6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0A7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0A8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0A9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0AA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0AB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0AC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0AD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0AE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0AF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0B0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0B1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0B2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0B3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0B4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0B5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0B6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0B7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0B8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0B9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0BA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0BB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0BC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0BD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0BE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0BF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0C0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0C1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0C2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0C3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0C4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0C5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0C6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0C7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0C8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0C9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0CA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0CB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0CC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0CD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0CE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0CF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0D0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0D1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0D2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0D3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0D4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0D5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0D6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0D7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0D8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0D9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0DA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0DB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0DC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0DD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0DE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0DF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0E0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0E1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0E2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0E3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0E4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0E5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0E6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0E7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0E8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0E9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0EA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0EB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0EC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0ED: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0EE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0EF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0F0: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0F1: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0F2: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0F3: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0F4: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0F5: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0F6: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0F7: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0F8: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0F9: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0FA: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0FB: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0FC: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0FD: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0FE: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h0FF: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h100: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h101: dout <= { 10'sd511   , -10'sd6     }; /* W[   8] =  0.9980  -0.0117i */
            10'h102: dout <= { 10'sd511   , -10'sd13    }; /* W[  16] =  0.9980  -0.0254i */
            10'h103: dout <= { 10'sd511   , -10'sd19    }; /* W[  24] =  0.9980  -0.0371i */
            10'h104: dout <= { 10'sd511   , -10'sd25    }; /* W[  32] =  0.9980  -0.0488i */
            10'h105: dout <= { 10'sd511   , -10'sd31    }; /* W[  40] =  0.9980  -0.0605i */
            10'h106: dout <= { 10'sd511   , -10'sd38    }; /* W[  48] =  0.9980  -0.0742i */
            10'h107: dout <= { 10'sd510   , -10'sd44    }; /* W[  56] =  0.9961  -0.0859i */
            10'h108: dout <= { 10'sd510   , -10'sd50    }; /* W[  64] =  0.9961  -0.0977i */
            10'h109: dout <= { 10'sd509   , -10'sd56    }; /* W[  72] =  0.9941  -0.1094i */
            10'h10A: dout <= { 10'sd508   , -10'sd63    }; /* W[  80] =  0.9922  -0.1230i */
            10'h10B: dout <= { 10'sd507   , -10'sd69    }; /* W[  88] =  0.9902  -0.1348i */
            10'h10C: dout <= { 10'sd506   , -10'sd75    }; /* W[  96] =  0.9883  -0.1465i */
            10'h10D: dout <= { 10'sd505   , -10'sd81    }; /* W[ 104] =  0.9863  -0.1582i */
            10'h10E: dout <= { 10'sd504   , -10'sd88    }; /* W[ 112] =  0.9844  -0.1719i */
            10'h10F: dout <= { 10'sd503   , -10'sd94    }; /* W[ 120] =  0.9824  -0.1836i */
            10'h110: dout <= { 10'sd502   , -10'sd100   }; /* W[ 128] =  0.9805  -0.1953i */
            10'h111: dout <= { 10'sd501   , -10'sd106   }; /* W[ 136] =  0.9785  -0.2070i */
            10'h112: dout <= { 10'sd500   , -10'sd112   }; /* W[ 144] =  0.9766  -0.2188i */
            10'h113: dout <= { 10'sd498   , -10'sd118   }; /* W[ 152] =  0.9727  -0.2305i */
            10'h114: dout <= { 10'sd497   , -10'sd124   }; /* W[ 160] =  0.9707  -0.2422i */
            10'h115: dout <= { 10'sd495   , -10'sd130   }; /* W[ 168] =  0.9668  -0.2539i */
            10'h116: dout <= { 10'sd493   , -10'sd137   }; /* W[ 176] =  0.9629  -0.2676i */
            10'h117: dout <= { 10'sd492   , -10'sd143   }; /* W[ 184] =  0.9609  -0.2793i */
            10'h118: dout <= { 10'sd490   , -10'sd149   }; /* W[ 192] =  0.9570  -0.2910i */
            10'h119: dout <= { 10'sd488   , -10'sd155   }; /* W[ 200] =  0.9531  -0.3027i */
            10'h11A: dout <= { 10'sd486   , -10'sd161   }; /* W[ 208] =  0.9492  -0.3145i */
            10'h11B: dout <= { 10'sd484   , -10'sd167   }; /* W[ 216] =  0.9453  -0.3262i */
            10'h11C: dout <= { 10'sd482   , -10'sd172   }; /* W[ 224] =  0.9414  -0.3359i */
            10'h11D: dout <= { 10'sd480   , -10'sd178   }; /* W[ 232] =  0.9375  -0.3477i */
            10'h11E: dout <= { 10'sd478   , -10'sd184   }; /* W[ 240] =  0.9336  -0.3594i */
            10'h11F: dout <= { 10'sd475   , -10'sd190   }; /* W[ 248] =  0.9277  -0.3711i */
            10'h120: dout <= { 10'sd473   , -10'sd196   }; /* W[ 256] =  0.9238  -0.3828i */
            10'h121: dout <= { 10'sd471   , -10'sd202   }; /* W[ 264] =  0.9199  -0.3945i */
            10'h122: dout <= { 10'sd468   , -10'sd207   }; /* W[ 272] =  0.9141  -0.4043i */
            10'h123: dout <= { 10'sd465   , -10'sd213   }; /* W[ 280] =  0.9082  -0.4160i */
            10'h124: dout <= { 10'sd463   , -10'sd219   }; /* W[ 288] =  0.9043  -0.4277i */
            10'h125: dout <= { 10'sd460   , -10'sd225   }; /* W[ 296] =  0.8984  -0.4395i */
            10'h126: dout <= { 10'sd457   , -10'sd230   }; /* W[ 304] =  0.8926  -0.4492i */
            10'h127: dout <= { 10'sd454   , -10'sd236   }; /* W[ 312] =  0.8867  -0.4609i */
            10'h128: dout <= { 10'sd452   , -10'sd241   }; /* W[ 320] =  0.8828  -0.4707i */
            10'h129: dout <= { 10'sd449   , -10'sd247   }; /* W[ 328] =  0.8770  -0.4824i */
            10'h12A: dout <= { 10'sd445   , -10'sd252   }; /* W[ 336] =  0.8691  -0.4922i */
            10'h12B: dout <= { 10'sd442   , -10'sd258   }; /* W[ 344] =  0.8633  -0.5039i */
            10'h12C: dout <= { 10'sd439   , -10'sd263   }; /* W[ 352] =  0.8574  -0.5137i */
            10'h12D: dout <= { 10'sd436   , -10'sd269   }; /* W[ 360] =  0.8516  -0.5254i */
            10'h12E: dout <= { 10'sd433   , -10'sd274   }; /* W[ 368] =  0.8457  -0.5352i */
            10'h12F: dout <= { 10'sd429   , -10'sd279   }; /* W[ 376] =  0.8379  -0.5449i */
            10'h130: dout <= { 10'sd426   , -10'sd284   }; /* W[ 384] =  0.8320  -0.5547i */
            10'h131: dout <= { 10'sd422   , -10'sd290   }; /* W[ 392] =  0.8242  -0.5664i */
            10'h132: dout <= { 10'sd419   , -10'sd295   }; /* W[ 400] =  0.8184  -0.5762i */
            10'h133: dout <= { 10'sd415   , -10'sd300   }; /* W[ 408] =  0.8105  -0.5859i */
            10'h134: dout <= { 10'sd411   , -10'sd305   }; /* W[ 416] =  0.8027  -0.5957i */
            10'h135: dout <= { 10'sd407   , -10'sd310   }; /* W[ 424] =  0.7949  -0.6055i */
            10'h136: dout <= { 10'sd404   , -10'sd315   }; /* W[ 432] =  0.7891  -0.6152i */
            10'h137: dout <= { 10'sd400   , -10'sd320   }; /* W[ 440] =  0.7812  -0.6250i */
            10'h138: dout <= { 10'sd396   , -10'sd325   }; /* W[ 448] =  0.7734  -0.6348i */
            10'h139: dout <= { 10'sd392   , -10'sd330   }; /* W[ 456] =  0.7656  -0.6445i */
            10'h13A: dout <= { 10'sd388   , -10'sd334   }; /* W[ 464] =  0.7578  -0.6523i */
            10'h13B: dout <= { 10'sd384   , -10'sd339   }; /* W[ 472] =  0.7500  -0.6621i */
            10'h13C: dout <= { 10'sd379   , -10'sd344   }; /* W[ 480] =  0.7402  -0.6719i */
            10'h13D: dout <= { 10'sd375   , -10'sd348   }; /* W[ 488] =  0.7324  -0.6797i */
            10'h13E: dout <= { 10'sd371   , -10'sd353   }; /* W[ 496] =  0.7246  -0.6895i */
            10'h13F: dout <= { 10'sd366   , -10'sd358   }; /* W[ 504] =  0.7148  -0.6992i */
            10'h140: dout <= { 10'sd362   , -10'sd362   }; /* W[ 512] =  0.7070  -0.7070i */
            10'h141: dout <= { 10'sd358   , -10'sd366   }; /* W[ 520] =  0.6992  -0.7148i */
            10'h142: dout <= { 10'sd353   , -10'sd371   }; /* W[ 528] =  0.6895  -0.7246i */
            10'h143: dout <= { 10'sd348   , -10'sd375   }; /* W[ 536] =  0.6797  -0.7324i */
            10'h144: dout <= { 10'sd344   , -10'sd379   }; /* W[ 544] =  0.6719  -0.7402i */
            10'h145: dout <= { 10'sd339   , -10'sd384   }; /* W[ 552] =  0.6621  -0.7500i */
            10'h146: dout <= { 10'sd334   , -10'sd388   }; /* W[ 560] =  0.6523  -0.7578i */
            10'h147: dout <= { 10'sd330   , -10'sd392   }; /* W[ 568] =  0.6445  -0.7656i */
            10'h148: dout <= { 10'sd325   , -10'sd396   }; /* W[ 576] =  0.6348  -0.7734i */
            10'h149: dout <= { 10'sd320   , -10'sd400   }; /* W[ 584] =  0.6250  -0.7812i */
            10'h14A: dout <= { 10'sd315   , -10'sd404   }; /* W[ 592] =  0.6152  -0.7891i */
            10'h14B: dout <= { 10'sd310   , -10'sd407   }; /* W[ 600] =  0.6055  -0.7949i */
            10'h14C: dout <= { 10'sd305   , -10'sd411   }; /* W[ 608] =  0.5957  -0.8027i */
            10'h14D: dout <= { 10'sd300   , -10'sd415   }; /* W[ 616] =  0.5859  -0.8105i */
            10'h14E: dout <= { 10'sd295   , -10'sd419   }; /* W[ 624] =  0.5762  -0.8184i */
            10'h14F: dout <= { 10'sd290   , -10'sd422   }; /* W[ 632] =  0.5664  -0.8242i */
            10'h150: dout <= { 10'sd284   , -10'sd426   }; /* W[ 640] =  0.5547  -0.8320i */
            10'h151: dout <= { 10'sd279   , -10'sd429   }; /* W[ 648] =  0.5449  -0.8379i */
            10'h152: dout <= { 10'sd274   , -10'sd433   }; /* W[ 656] =  0.5352  -0.8457i */
            10'h153: dout <= { 10'sd269   , -10'sd436   }; /* W[ 664] =  0.5254  -0.8516i */
            10'h154: dout <= { 10'sd263   , -10'sd439   }; /* W[ 672] =  0.5137  -0.8574i */
            10'h155: dout <= { 10'sd258   , -10'sd442   }; /* W[ 680] =  0.5039  -0.8633i */
            10'h156: dout <= { 10'sd252   , -10'sd445   }; /* W[ 688] =  0.4922  -0.8691i */
            10'h157: dout <= { 10'sd247   , -10'sd449   }; /* W[ 696] =  0.4824  -0.8770i */
            10'h158: dout <= { 10'sd241   , -10'sd452   }; /* W[ 704] =  0.4707  -0.8828i */
            10'h159: dout <= { 10'sd236   , -10'sd454   }; /* W[ 712] =  0.4609  -0.8867i */
            10'h15A: dout <= { 10'sd230   , -10'sd457   }; /* W[ 720] =  0.4492  -0.8926i */
            10'h15B: dout <= { 10'sd225   , -10'sd460   }; /* W[ 728] =  0.4395  -0.8984i */
            10'h15C: dout <= { 10'sd219   , -10'sd463   }; /* W[ 736] =  0.4277  -0.9043i */
            10'h15D: dout <= { 10'sd213   , -10'sd465   }; /* W[ 744] =  0.4160  -0.9082i */
            10'h15E: dout <= { 10'sd207   , -10'sd468   }; /* W[ 752] =  0.4043  -0.9141i */
            10'h15F: dout <= { 10'sd202   , -10'sd471   }; /* W[ 760] =  0.3945  -0.9199i */
            10'h160: dout <= { 10'sd196   , -10'sd473   }; /* W[ 768] =  0.3828  -0.9238i */
            10'h161: dout <= { 10'sd190   , -10'sd475   }; /* W[ 776] =  0.3711  -0.9277i */
            10'h162: dout <= { 10'sd184   , -10'sd478   }; /* W[ 784] =  0.3594  -0.9336i */
            10'h163: dout <= { 10'sd178   , -10'sd480   }; /* W[ 792] =  0.3477  -0.9375i */
            10'h164: dout <= { 10'sd172   , -10'sd482   }; /* W[ 800] =  0.3359  -0.9414i */
            10'h165: dout <= { 10'sd167   , -10'sd484   }; /* W[ 808] =  0.3262  -0.9453i */
            10'h166: dout <= { 10'sd161   , -10'sd486   }; /* W[ 816] =  0.3145  -0.9492i */
            10'h167: dout <= { 10'sd155   , -10'sd488   }; /* W[ 824] =  0.3027  -0.9531i */
            10'h168: dout <= { 10'sd149   , -10'sd490   }; /* W[ 832] =  0.2910  -0.9570i */
            10'h169: dout <= { 10'sd143   , -10'sd492   }; /* W[ 840] =  0.2793  -0.9609i */
            10'h16A: dout <= { 10'sd137   , -10'sd493   }; /* W[ 848] =  0.2676  -0.9629i */
            10'h16B: dout <= { 10'sd130   , -10'sd495   }; /* W[ 856] =  0.2539  -0.9668i */
            10'h16C: dout <= { 10'sd124   , -10'sd497   }; /* W[ 864] =  0.2422  -0.9707i */
            10'h16D: dout <= { 10'sd118   , -10'sd498   }; /* W[ 872] =  0.2305  -0.9727i */
            10'h16E: dout <= { 10'sd112   , -10'sd500   }; /* W[ 880] =  0.2188  -0.9766i */
            10'h16F: dout <= { 10'sd106   , -10'sd501   }; /* W[ 888] =  0.2070  -0.9785i */
            10'h170: dout <= { 10'sd100   , -10'sd502   }; /* W[ 896] =  0.1953  -0.9805i */
            10'h171: dout <= { 10'sd94    , -10'sd503   }; /* W[ 904] =  0.1836  -0.9824i */
            10'h172: dout <= { 10'sd88    , -10'sd504   }; /* W[ 912] =  0.1719  -0.9844i */
            10'h173: dout <= { 10'sd81    , -10'sd505   }; /* W[ 920] =  0.1582  -0.9863i */
            10'h174: dout <= { 10'sd75    , -10'sd506   }; /* W[ 928] =  0.1465  -0.9883i */
            10'h175: dout <= { 10'sd69    , -10'sd507   }; /* W[ 936] =  0.1348  -0.9902i */
            10'h176: dout <= { 10'sd63    , -10'sd508   }; /* W[ 944] =  0.1230  -0.9922i */
            10'h177: dout <= { 10'sd56    , -10'sd509   }; /* W[ 952] =  0.1094  -0.9941i */
            10'h178: dout <= { 10'sd50    , -10'sd510   }; /* W[ 960] =  0.0977  -0.9961i */
            10'h179: dout <= { 10'sd44    , -10'sd510   }; /* W[ 968] =  0.0859  -0.9961i */
            10'h17A: dout <= { 10'sd38    , -10'sd511   }; /* W[ 976] =  0.0742  -0.9980i */
            10'h17B: dout <= { 10'sd31    , -10'sd511   }; /* W[ 984] =  0.0605  -0.9980i */
            10'h17C: dout <= { 10'sd25    , -10'sd511   }; /* W[ 992] =  0.0488  -0.9980i */
            10'h17D: dout <= { 10'sd19    , -10'sd512   }; /* W[1000] =  0.0371  -1.0000i */
            10'h17E: dout <= { 10'sd13    , -10'sd512   }; /* W[1008] =  0.0254  -1.0000i */
            10'h17F: dout <= { 10'sd6     , -10'sd512   }; /* W[1016] =  0.0117  -1.0000i */
            10'h180: dout <= { 10'sd0     , -10'sd512   }; /* W[1024] =  0.0000  -1.0000i */
            10'h181: dout <= {-10'sd6     , -10'sd512   }; /* W[1032] = -0.0117  -1.0000i */
            10'h182: dout <= {-10'sd13    , -10'sd512   }; /* W[1040] = -0.0254  -1.0000i */
            10'h183: dout <= {-10'sd19    , -10'sd512   }; /* W[1048] = -0.0371  -1.0000i */
            10'h184: dout <= {-10'sd25    , -10'sd511   }; /* W[1056] = -0.0488  -0.9980i */
            10'h185: dout <= {-10'sd31    , -10'sd511   }; /* W[1064] = -0.0605  -0.9980i */
            10'h186: dout <= {-10'sd38    , -10'sd511   }; /* W[1072] = -0.0742  -0.9980i */
            10'h187: dout <= {-10'sd44    , -10'sd510   }; /* W[1080] = -0.0859  -0.9961i */
            10'h188: dout <= {-10'sd50    , -10'sd510   }; /* W[1088] = -0.0977  -0.9961i */
            10'h189: dout <= {-10'sd56    , -10'sd509   }; /* W[1096] = -0.1094  -0.9941i */
            10'h18A: dout <= {-10'sd63    , -10'sd508   }; /* W[1104] = -0.1230  -0.9922i */
            10'h18B: dout <= {-10'sd69    , -10'sd507   }; /* W[1112] = -0.1348  -0.9902i */
            10'h18C: dout <= {-10'sd75    , -10'sd506   }; /* W[1120] = -0.1465  -0.9883i */
            10'h18D: dout <= {-10'sd81    , -10'sd505   }; /* W[1128] = -0.1582  -0.9863i */
            10'h18E: dout <= {-10'sd88    , -10'sd504   }; /* W[1136] = -0.1719  -0.9844i */
            10'h18F: dout <= {-10'sd94    , -10'sd503   }; /* W[1144] = -0.1836  -0.9824i */
            10'h190: dout <= {-10'sd100   , -10'sd502   }; /* W[1152] = -0.1953  -0.9805i */
            10'h191: dout <= {-10'sd106   , -10'sd501   }; /* W[1160] = -0.2070  -0.9785i */
            10'h192: dout <= {-10'sd112   , -10'sd500   }; /* W[1168] = -0.2188  -0.9766i */
            10'h193: dout <= {-10'sd118   , -10'sd498   }; /* W[1176] = -0.2305  -0.9727i */
            10'h194: dout <= {-10'sd124   , -10'sd497   }; /* W[1184] = -0.2422  -0.9707i */
            10'h195: dout <= {-10'sd130   , -10'sd495   }; /* W[1192] = -0.2539  -0.9668i */
            10'h196: dout <= {-10'sd137   , -10'sd493   }; /* W[1200] = -0.2676  -0.9629i */
            10'h197: dout <= {-10'sd143   , -10'sd492   }; /* W[1208] = -0.2793  -0.9609i */
            10'h198: dout <= {-10'sd149   , -10'sd490   }; /* W[1216] = -0.2910  -0.9570i */
            10'h199: dout <= {-10'sd155   , -10'sd488   }; /* W[1224] = -0.3027  -0.9531i */
            10'h19A: dout <= {-10'sd161   , -10'sd486   }; /* W[1232] = -0.3145  -0.9492i */
            10'h19B: dout <= {-10'sd167   , -10'sd484   }; /* W[1240] = -0.3262  -0.9453i */
            10'h19C: dout <= {-10'sd172   , -10'sd482   }; /* W[1248] = -0.3359  -0.9414i */
            10'h19D: dout <= {-10'sd178   , -10'sd480   }; /* W[1256] = -0.3477  -0.9375i */
            10'h19E: dout <= {-10'sd184   , -10'sd478   }; /* W[1264] = -0.3594  -0.9336i */
            10'h19F: dout <= {-10'sd190   , -10'sd475   }; /* W[1272] = -0.3711  -0.9277i */
            10'h1A0: dout <= {-10'sd196   , -10'sd473   }; /* W[1280] = -0.3828  -0.9238i */
            10'h1A1: dout <= {-10'sd202   , -10'sd471   }; /* W[1288] = -0.3945  -0.9199i */
            10'h1A2: dout <= {-10'sd207   , -10'sd468   }; /* W[1296] = -0.4043  -0.9141i */
            10'h1A3: dout <= {-10'sd213   , -10'sd465   }; /* W[1304] = -0.4160  -0.9082i */
            10'h1A4: dout <= {-10'sd219   , -10'sd463   }; /* W[1312] = -0.4277  -0.9043i */
            10'h1A5: dout <= {-10'sd225   , -10'sd460   }; /* W[1320] = -0.4395  -0.8984i */
            10'h1A6: dout <= {-10'sd230   , -10'sd457   }; /* W[1328] = -0.4492  -0.8926i */
            10'h1A7: dout <= {-10'sd236   , -10'sd454   }; /* W[1336] = -0.4609  -0.8867i */
            10'h1A8: dout <= {-10'sd241   , -10'sd452   }; /* W[1344] = -0.4707  -0.8828i */
            10'h1A9: dout <= {-10'sd247   , -10'sd449   }; /* W[1352] = -0.4824  -0.8770i */
            10'h1AA: dout <= {-10'sd252   , -10'sd445   }; /* W[1360] = -0.4922  -0.8691i */
            10'h1AB: dout <= {-10'sd258   , -10'sd442   }; /* W[1368] = -0.5039  -0.8633i */
            10'h1AC: dout <= {-10'sd263   , -10'sd439   }; /* W[1376] = -0.5137  -0.8574i */
            10'h1AD: dout <= {-10'sd269   , -10'sd436   }; /* W[1384] = -0.5254  -0.8516i */
            10'h1AE: dout <= {-10'sd274   , -10'sd433   }; /* W[1392] = -0.5352  -0.8457i */
            10'h1AF: dout <= {-10'sd279   , -10'sd429   }; /* W[1400] = -0.5449  -0.8379i */
            10'h1B0: dout <= {-10'sd284   , -10'sd426   }; /* W[1408] = -0.5547  -0.8320i */
            10'h1B1: dout <= {-10'sd290   , -10'sd422   }; /* W[1416] = -0.5664  -0.8242i */
            10'h1B2: dout <= {-10'sd295   , -10'sd419   }; /* W[1424] = -0.5762  -0.8184i */
            10'h1B3: dout <= {-10'sd300   , -10'sd415   }; /* W[1432] = -0.5859  -0.8105i */
            10'h1B4: dout <= {-10'sd305   , -10'sd411   }; /* W[1440] = -0.5957  -0.8027i */
            10'h1B5: dout <= {-10'sd310   , -10'sd407   }; /* W[1448] = -0.6055  -0.7949i */
            10'h1B6: dout <= {-10'sd315   , -10'sd404   }; /* W[1456] = -0.6152  -0.7891i */
            10'h1B7: dout <= {-10'sd320   , -10'sd400   }; /* W[1464] = -0.6250  -0.7812i */
            10'h1B8: dout <= {-10'sd325   , -10'sd396   }; /* W[1472] = -0.6348  -0.7734i */
            10'h1B9: dout <= {-10'sd330   , -10'sd392   }; /* W[1480] = -0.6445  -0.7656i */
            10'h1BA: dout <= {-10'sd334   , -10'sd388   }; /* W[1488] = -0.6523  -0.7578i */
            10'h1BB: dout <= {-10'sd339   , -10'sd384   }; /* W[1496] = -0.6621  -0.7500i */
            10'h1BC: dout <= {-10'sd344   , -10'sd379   }; /* W[1504] = -0.6719  -0.7402i */
            10'h1BD: dout <= {-10'sd348   , -10'sd375   }; /* W[1512] = -0.6797  -0.7324i */
            10'h1BE: dout <= {-10'sd353   , -10'sd371   }; /* W[1520] = -0.6895  -0.7246i */
            10'h1BF: dout <= {-10'sd358   , -10'sd366   }; /* W[1528] = -0.6992  -0.7148i */
            10'h1C0: dout <= {-10'sd362   , -10'sd362   }; /* W[1536] = -0.7070  -0.7070i */
            10'h1C1: dout <= {-10'sd366   , -10'sd358   }; /* W[1544] = -0.7148  -0.6992i */
            10'h1C2: dout <= {-10'sd371   , -10'sd353   }; /* W[1552] = -0.7246  -0.6895i */
            10'h1C3: dout <= {-10'sd375   , -10'sd348   }; /* W[1560] = -0.7324  -0.6797i */
            10'h1C4: dout <= {-10'sd379   , -10'sd344   }; /* W[1568] = -0.7402  -0.6719i */
            10'h1C5: dout <= {-10'sd384   , -10'sd339   }; /* W[1576] = -0.7500  -0.6621i */
            10'h1C6: dout <= {-10'sd388   , -10'sd334   }; /* W[1584] = -0.7578  -0.6523i */
            10'h1C7: dout <= {-10'sd392   , -10'sd330   }; /* W[1592] = -0.7656  -0.6445i */
            10'h1C8: dout <= {-10'sd396   , -10'sd325   }; /* W[1600] = -0.7734  -0.6348i */
            10'h1C9: dout <= {-10'sd400   , -10'sd320   }; /* W[1608] = -0.7812  -0.6250i */
            10'h1CA: dout <= {-10'sd404   , -10'sd315   }; /* W[1616] = -0.7891  -0.6152i */
            10'h1CB: dout <= {-10'sd407   , -10'sd310   }; /* W[1624] = -0.7949  -0.6055i */
            10'h1CC: dout <= {-10'sd411   , -10'sd305   }; /* W[1632] = -0.8027  -0.5957i */
            10'h1CD: dout <= {-10'sd415   , -10'sd300   }; /* W[1640] = -0.8105  -0.5859i */
            10'h1CE: dout <= {-10'sd419   , -10'sd295   }; /* W[1648] = -0.8184  -0.5762i */
            10'h1CF: dout <= {-10'sd422   , -10'sd290   }; /* W[1656] = -0.8242  -0.5664i */
            10'h1D0: dout <= {-10'sd426   , -10'sd284   }; /* W[1664] = -0.8320  -0.5547i */
            10'h1D1: dout <= {-10'sd429   , -10'sd279   }; /* W[1672] = -0.8379  -0.5449i */
            10'h1D2: dout <= {-10'sd433   , -10'sd274   }; /* W[1680] = -0.8457  -0.5352i */
            10'h1D3: dout <= {-10'sd436   , -10'sd269   }; /* W[1688] = -0.8516  -0.5254i */
            10'h1D4: dout <= {-10'sd439   , -10'sd263   }; /* W[1696] = -0.8574  -0.5137i */
            10'h1D5: dout <= {-10'sd442   , -10'sd258   }; /* W[1704] = -0.8633  -0.5039i */
            10'h1D6: dout <= {-10'sd445   , -10'sd252   }; /* W[1712] = -0.8691  -0.4922i */
            10'h1D7: dout <= {-10'sd449   , -10'sd247   }; /* W[1720] = -0.8770  -0.4824i */
            10'h1D8: dout <= {-10'sd452   , -10'sd241   }; /* W[1728] = -0.8828  -0.4707i */
            10'h1D9: dout <= {-10'sd454   , -10'sd236   }; /* W[1736] = -0.8867  -0.4609i */
            10'h1DA: dout <= {-10'sd457   , -10'sd230   }; /* W[1744] = -0.8926  -0.4492i */
            10'h1DB: dout <= {-10'sd460   , -10'sd225   }; /* W[1752] = -0.8984  -0.4395i */
            10'h1DC: dout <= {-10'sd463   , -10'sd219   }; /* W[1760] = -0.9043  -0.4277i */
            10'h1DD: dout <= {-10'sd465   , -10'sd213   }; /* W[1768] = -0.9082  -0.4160i */
            10'h1DE: dout <= {-10'sd468   , -10'sd207   }; /* W[1776] = -0.9141  -0.4043i */
            10'h1DF: dout <= {-10'sd471   , -10'sd202   }; /* W[1784] = -0.9199  -0.3945i */
            10'h1E0: dout <= {-10'sd473   , -10'sd196   }; /* W[1792] = -0.9238  -0.3828i */
            10'h1E1: dout <= {-10'sd475   , -10'sd190   }; /* W[1800] = -0.9277  -0.3711i */
            10'h1E2: dout <= {-10'sd478   , -10'sd184   }; /* W[1808] = -0.9336  -0.3594i */
            10'h1E3: dout <= {-10'sd480   , -10'sd178   }; /* W[1816] = -0.9375  -0.3477i */
            10'h1E4: dout <= {-10'sd482   , -10'sd172   }; /* W[1824] = -0.9414  -0.3359i */
            10'h1E5: dout <= {-10'sd484   , -10'sd167   }; /* W[1832] = -0.9453  -0.3262i */
            10'h1E6: dout <= {-10'sd486   , -10'sd161   }; /* W[1840] = -0.9492  -0.3145i */
            10'h1E7: dout <= {-10'sd488   , -10'sd155   }; /* W[1848] = -0.9531  -0.3027i */
            10'h1E8: dout <= {-10'sd490   , -10'sd149   }; /* W[1856] = -0.9570  -0.2910i */
            10'h1E9: dout <= {-10'sd492   , -10'sd143   }; /* W[1864] = -0.9609  -0.2793i */
            10'h1EA: dout <= {-10'sd493   , -10'sd137   }; /* W[1872] = -0.9629  -0.2676i */
            10'h1EB: dout <= {-10'sd495   , -10'sd130   }; /* W[1880] = -0.9668  -0.2539i */
            10'h1EC: dout <= {-10'sd497   , -10'sd124   }; /* W[1888] = -0.9707  -0.2422i */
            10'h1ED: dout <= {-10'sd498   , -10'sd118   }; /* W[1896] = -0.9727  -0.2305i */
            10'h1EE: dout <= {-10'sd500   , -10'sd112   }; /* W[1904] = -0.9766  -0.2188i */
            10'h1EF: dout <= {-10'sd501   , -10'sd106   }; /* W[1912] = -0.9785  -0.2070i */
            10'h1F0: dout <= {-10'sd502   , -10'sd100   }; /* W[1920] = -0.9805  -0.1953i */
            10'h1F1: dout <= {-10'sd503   , -10'sd94    }; /* W[1928] = -0.9824  -0.1836i */
            10'h1F2: dout <= {-10'sd504   , -10'sd88    }; /* W[1936] = -0.9844  -0.1719i */
            10'h1F3: dout <= {-10'sd505   , -10'sd81    }; /* W[1944] = -0.9863  -0.1582i */
            10'h1F4: dout <= {-10'sd506   , -10'sd75    }; /* W[1952] = -0.9883  -0.1465i */
            10'h1F5: dout <= {-10'sd507   , -10'sd69    }; /* W[1960] = -0.9902  -0.1348i */
            10'h1F6: dout <= {-10'sd508   , -10'sd63    }; /* W[1968] = -0.9922  -0.1230i */
            10'h1F7: dout <= {-10'sd509   , -10'sd56    }; /* W[1976] = -0.9941  -0.1094i */
            10'h1F8: dout <= {-10'sd510   , -10'sd50    }; /* W[1984] = -0.9961  -0.0977i */
            10'h1F9: dout <= {-10'sd510   , -10'sd44    }; /* W[1992] = -0.9961  -0.0859i */
            10'h1FA: dout <= {-10'sd511   , -10'sd38    }; /* W[2000] = -0.9980  -0.0742i */
            10'h1FB: dout <= {-10'sd511   , -10'sd31    }; /* W[2008] = -0.9980  -0.0605i */
            10'h1FC: dout <= {-10'sd511   , -10'sd25    }; /* W[2016] = -0.9980  -0.0488i */
            10'h1FD: dout <= {-10'sd512   , -10'sd19    }; /* W[2024] = -1.0000  -0.0371i */
            10'h1FE: dout <= {-10'sd512   , -10'sd13    }; /* W[2032] = -1.0000  -0.0254i */
            10'h1FF: dout <= {-10'sd512   , -10'sd6     }; /* W[2040] = -1.0000  -0.0117i */
            10'h200: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h201: dout <= { 10'sd511   , -10'sd3     }; /* W[   4] =  0.9980  -0.0059i */
            10'h202: dout <= { 10'sd511   , -10'sd6     }; /* W[   8] =  0.9980  -0.0117i */
            10'h203: dout <= { 10'sd511   , -10'sd9     }; /* W[  12] =  0.9980  -0.0176i */
            10'h204: dout <= { 10'sd511   , -10'sd13    }; /* W[  16] =  0.9980  -0.0254i */
            10'h205: dout <= { 10'sd511   , -10'sd16    }; /* W[  20] =  0.9980  -0.0312i */
            10'h206: dout <= { 10'sd511   , -10'sd19    }; /* W[  24] =  0.9980  -0.0371i */
            10'h207: dout <= { 10'sd511   , -10'sd22    }; /* W[  28] =  0.9980  -0.0430i */
            10'h208: dout <= { 10'sd511   , -10'sd25    }; /* W[  32] =  0.9980  -0.0488i */
            10'h209: dout <= { 10'sd511   , -10'sd28    }; /* W[  36] =  0.9980  -0.0547i */
            10'h20A: dout <= { 10'sd511   , -10'sd31    }; /* W[  40] =  0.9980  -0.0605i */
            10'h20B: dout <= { 10'sd511   , -10'sd35    }; /* W[  44] =  0.9980  -0.0684i */
            10'h20C: dout <= { 10'sd511   , -10'sd38    }; /* W[  48] =  0.9980  -0.0742i */
            10'h20D: dout <= { 10'sd510   , -10'sd41    }; /* W[  52] =  0.9961  -0.0801i */
            10'h20E: dout <= { 10'sd510   , -10'sd44    }; /* W[  56] =  0.9961  -0.0859i */
            10'h20F: dout <= { 10'sd510   , -10'sd47    }; /* W[  60] =  0.9961  -0.0918i */
            10'h210: dout <= { 10'sd510   , -10'sd50    }; /* W[  64] =  0.9961  -0.0977i */
            10'h211: dout <= { 10'sd509   , -10'sd53    }; /* W[  68] =  0.9941  -0.1035i */
            10'h212: dout <= { 10'sd509   , -10'sd56    }; /* W[  72] =  0.9941  -0.1094i */
            10'h213: dout <= { 10'sd509   , -10'sd60    }; /* W[  76] =  0.9941  -0.1172i */
            10'h214: dout <= { 10'sd508   , -10'sd63    }; /* W[  80] =  0.9922  -0.1230i */
            10'h215: dout <= { 10'sd508   , -10'sd66    }; /* W[  84] =  0.9922  -0.1289i */
            10'h216: dout <= { 10'sd507   , -10'sd69    }; /* W[  88] =  0.9902  -0.1348i */
            10'h217: dout <= { 10'sd507   , -10'sd72    }; /* W[  92] =  0.9902  -0.1406i */
            10'h218: dout <= { 10'sd506   , -10'sd75    }; /* W[  96] =  0.9883  -0.1465i */
            10'h219: dout <= { 10'sd506   , -10'sd78    }; /* W[ 100] =  0.9883  -0.1523i */
            10'h21A: dout <= { 10'sd505   , -10'sd81    }; /* W[ 104] =  0.9863  -0.1582i */
            10'h21B: dout <= { 10'sd505   , -10'sd84    }; /* W[ 108] =  0.9863  -0.1641i */
            10'h21C: dout <= { 10'sd504   , -10'sd88    }; /* W[ 112] =  0.9844  -0.1719i */
            10'h21D: dout <= { 10'sd504   , -10'sd91    }; /* W[ 116] =  0.9844  -0.1777i */
            10'h21E: dout <= { 10'sd503   , -10'sd94    }; /* W[ 120] =  0.9824  -0.1836i */
            10'h21F: dout <= { 10'sd503   , -10'sd97    }; /* W[ 124] =  0.9824  -0.1895i */
            10'h220: dout <= { 10'sd502   , -10'sd100   }; /* W[ 128] =  0.9805  -0.1953i */
            10'h221: dout <= { 10'sd502   , -10'sd103   }; /* W[ 132] =  0.9805  -0.2012i */
            10'h222: dout <= { 10'sd501   , -10'sd106   }; /* W[ 136] =  0.9785  -0.2070i */
            10'h223: dout <= { 10'sd500   , -10'sd109   }; /* W[ 140] =  0.9766  -0.2129i */
            10'h224: dout <= { 10'sd500   , -10'sd112   }; /* W[ 144] =  0.9766  -0.2188i */
            10'h225: dout <= { 10'sd499   , -10'sd115   }; /* W[ 148] =  0.9746  -0.2246i */
            10'h226: dout <= { 10'sd498   , -10'sd118   }; /* W[ 152] =  0.9727  -0.2305i */
            10'h227: dout <= { 10'sd497   , -10'sd121   }; /* W[ 156] =  0.9707  -0.2363i */
            10'h228: dout <= { 10'sd497   , -10'sd124   }; /* W[ 160] =  0.9707  -0.2422i */
            10'h229: dout <= { 10'sd496   , -10'sd127   }; /* W[ 164] =  0.9688  -0.2480i */
            10'h22A: dout <= { 10'sd495   , -10'sd130   }; /* W[ 168] =  0.9668  -0.2539i */
            10'h22B: dout <= { 10'sd494   , -10'sd134   }; /* W[ 172] =  0.9648  -0.2617i */
            10'h22C: dout <= { 10'sd493   , -10'sd137   }; /* W[ 176] =  0.9629  -0.2676i */
            10'h22D: dout <= { 10'sd493   , -10'sd140   }; /* W[ 180] =  0.9629  -0.2734i */
            10'h22E: dout <= { 10'sd492   , -10'sd143   }; /* W[ 184] =  0.9609  -0.2793i */
            10'h22F: dout <= { 10'sd491   , -10'sd146   }; /* W[ 188] =  0.9590  -0.2852i */
            10'h230: dout <= { 10'sd490   , -10'sd149   }; /* W[ 192] =  0.9570  -0.2910i */
            10'h231: dout <= { 10'sd489   , -10'sd152   }; /* W[ 196] =  0.9551  -0.2969i */
            10'h232: dout <= { 10'sd488   , -10'sd155   }; /* W[ 200] =  0.9531  -0.3027i */
            10'h233: dout <= { 10'sd487   , -10'sd158   }; /* W[ 204] =  0.9512  -0.3086i */
            10'h234: dout <= { 10'sd486   , -10'sd161   }; /* W[ 208] =  0.9492  -0.3145i */
            10'h235: dout <= { 10'sd485   , -10'sd164   }; /* W[ 212] =  0.9473  -0.3203i */
            10'h236: dout <= { 10'sd484   , -10'sd167   }; /* W[ 216] =  0.9453  -0.3262i */
            10'h237: dout <= { 10'sd483   , -10'sd170   }; /* W[ 220] =  0.9434  -0.3320i */
            10'h238: dout <= { 10'sd482   , -10'sd172   }; /* W[ 224] =  0.9414  -0.3359i */
            10'h239: dout <= { 10'sd481   , -10'sd175   }; /* W[ 228] =  0.9395  -0.3418i */
            10'h23A: dout <= { 10'sd480   , -10'sd178   }; /* W[ 232] =  0.9375  -0.3477i */
            10'h23B: dout <= { 10'sd479   , -10'sd181   }; /* W[ 236] =  0.9355  -0.3535i */
            10'h23C: dout <= { 10'sd478   , -10'sd184   }; /* W[ 240] =  0.9336  -0.3594i */
            10'h23D: dout <= { 10'sd477   , -10'sd187   }; /* W[ 244] =  0.9316  -0.3652i */
            10'h23E: dout <= { 10'sd475   , -10'sd190   }; /* W[ 248] =  0.9277  -0.3711i */
            10'h23F: dout <= { 10'sd474   , -10'sd193   }; /* W[ 252] =  0.9258  -0.3770i */
            10'h240: dout <= { 10'sd473   , -10'sd196   }; /* W[ 256] =  0.9238  -0.3828i */
            10'h241: dout <= { 10'sd472   , -10'sd199   }; /* W[ 260] =  0.9219  -0.3887i */
            10'h242: dout <= { 10'sd471   , -10'sd202   }; /* W[ 264] =  0.9199  -0.3945i */
            10'h243: dout <= { 10'sd469   , -10'sd205   }; /* W[ 268] =  0.9160  -0.4004i */
            10'h244: dout <= { 10'sd468   , -10'sd207   }; /* W[ 272] =  0.9141  -0.4043i */
            10'h245: dout <= { 10'sd467   , -10'sd210   }; /* W[ 276] =  0.9121  -0.4102i */
            10'h246: dout <= { 10'sd465   , -10'sd213   }; /* W[ 280] =  0.9082  -0.4160i */
            10'h247: dout <= { 10'sd464   , -10'sd216   }; /* W[ 284] =  0.9062  -0.4219i */
            10'h248: dout <= { 10'sd463   , -10'sd219   }; /* W[ 288] =  0.9043  -0.4277i */
            10'h249: dout <= { 10'sd461   , -10'sd222   }; /* W[ 292] =  0.9004  -0.4336i */
            10'h24A: dout <= { 10'sd460   , -10'sd225   }; /* W[ 296] =  0.8984  -0.4395i */
            10'h24B: dout <= { 10'sd459   , -10'sd227   }; /* W[ 300] =  0.8965  -0.4434i */
            10'h24C: dout <= { 10'sd457   , -10'sd230   }; /* W[ 304] =  0.8926  -0.4492i */
            10'h24D: dout <= { 10'sd456   , -10'sd233   }; /* W[ 308] =  0.8906  -0.4551i */
            10'h24E: dout <= { 10'sd454   , -10'sd236   }; /* W[ 312] =  0.8867  -0.4609i */
            10'h24F: dout <= { 10'sd453   , -10'sd239   }; /* W[ 316] =  0.8848  -0.4668i */
            10'h250: dout <= { 10'sd452   , -10'sd241   }; /* W[ 320] =  0.8828  -0.4707i */
            10'h251: dout <= { 10'sd450   , -10'sd244   }; /* W[ 324] =  0.8789  -0.4766i */
            10'h252: dout <= { 10'sd449   , -10'sd247   }; /* W[ 328] =  0.8770  -0.4824i */
            10'h253: dout <= { 10'sd447   , -10'sd250   }; /* W[ 332] =  0.8730  -0.4883i */
            10'h254: dout <= { 10'sd445   , -10'sd252   }; /* W[ 336] =  0.8691  -0.4922i */
            10'h255: dout <= { 10'sd444   , -10'sd255   }; /* W[ 340] =  0.8672  -0.4980i */
            10'h256: dout <= { 10'sd442   , -10'sd258   }; /* W[ 344] =  0.8633  -0.5039i */
            10'h257: dout <= { 10'sd441   , -10'sd261   }; /* W[ 348] =  0.8613  -0.5098i */
            10'h258: dout <= { 10'sd439   , -10'sd263   }; /* W[ 352] =  0.8574  -0.5137i */
            10'h259: dout <= { 10'sd438   , -10'sd266   }; /* W[ 356] =  0.8555  -0.5195i */
            10'h25A: dout <= { 10'sd436   , -10'sd269   }; /* W[ 360] =  0.8516  -0.5254i */
            10'h25B: dout <= { 10'sd434   , -10'sd271   }; /* W[ 364] =  0.8477  -0.5293i */
            10'h25C: dout <= { 10'sd433   , -10'sd274   }; /* W[ 368] =  0.8457  -0.5352i */
            10'h25D: dout <= { 10'sd431   , -10'sd277   }; /* W[ 372] =  0.8418  -0.5410i */
            10'h25E: dout <= { 10'sd429   , -10'sd279   }; /* W[ 376] =  0.8379  -0.5449i */
            10'h25F: dout <= { 10'sd427   , -10'sd282   }; /* W[ 380] =  0.8340  -0.5508i */
            10'h260: dout <= { 10'sd426   , -10'sd284   }; /* W[ 384] =  0.8320  -0.5547i */
            10'h261: dout <= { 10'sd424   , -10'sd287   }; /* W[ 388] =  0.8281  -0.5605i */
            10'h262: dout <= { 10'sd422   , -10'sd290   }; /* W[ 392] =  0.8242  -0.5664i */
            10'h263: dout <= { 10'sd420   , -10'sd292   }; /* W[ 396] =  0.8203  -0.5703i */
            10'h264: dout <= { 10'sd419   , -10'sd295   }; /* W[ 400] =  0.8184  -0.5762i */
            10'h265: dout <= { 10'sd417   , -10'sd297   }; /* W[ 404] =  0.8145  -0.5801i */
            10'h266: dout <= { 10'sd415   , -10'sd300   }; /* W[ 408] =  0.8105  -0.5859i */
            10'h267: dout <= { 10'sd413   , -10'sd302   }; /* W[ 412] =  0.8066  -0.5898i */
            10'h268: dout <= { 10'sd411   , -10'sd305   }; /* W[ 416] =  0.8027  -0.5957i */
            10'h269: dout <= { 10'sd409   , -10'sd308   }; /* W[ 420] =  0.7988  -0.6016i */
            10'h26A: dout <= { 10'sd407   , -10'sd310   }; /* W[ 424] =  0.7949  -0.6055i */
            10'h26B: dout <= { 10'sd406   , -10'sd313   }; /* W[ 428] =  0.7930  -0.6113i */
            10'h26C: dout <= { 10'sd404   , -10'sd315   }; /* W[ 432] =  0.7891  -0.6152i */
            10'h26D: dout <= { 10'sd402   , -10'sd317   }; /* W[ 436] =  0.7852  -0.6191i */
            10'h26E: dout <= { 10'sd400   , -10'sd320   }; /* W[ 440] =  0.7812  -0.6250i */
            10'h26F: dout <= { 10'sd398   , -10'sd322   }; /* W[ 444] =  0.7773  -0.6289i */
            10'h270: dout <= { 10'sd396   , -10'sd325   }; /* W[ 448] =  0.7734  -0.6348i */
            10'h271: dout <= { 10'sd394   , -10'sd327   }; /* W[ 452] =  0.7695  -0.6387i */
            10'h272: dout <= { 10'sd392   , -10'sd330   }; /* W[ 456] =  0.7656  -0.6445i */
            10'h273: dout <= { 10'sd390   , -10'sd332   }; /* W[ 460] =  0.7617  -0.6484i */
            10'h274: dout <= { 10'sd388   , -10'sd334   }; /* W[ 464] =  0.7578  -0.6523i */
            10'h275: dout <= { 10'sd386   , -10'sd337   }; /* W[ 468] =  0.7539  -0.6582i */
            10'h276: dout <= { 10'sd384   , -10'sd339   }; /* W[ 472] =  0.7500  -0.6621i */
            10'h277: dout <= { 10'sd381   , -10'sd342   }; /* W[ 476] =  0.7441  -0.6680i */
            10'h278: dout <= { 10'sd379   , -10'sd344   }; /* W[ 480] =  0.7402  -0.6719i */
            10'h279: dout <= { 10'sd377   , -10'sd346   }; /* W[ 484] =  0.7363  -0.6758i */
            10'h27A: dout <= { 10'sd375   , -10'sd348   }; /* W[ 488] =  0.7324  -0.6797i */
            10'h27B: dout <= { 10'sd373   , -10'sd351   }; /* W[ 492] =  0.7285  -0.6855i */
            10'h27C: dout <= { 10'sd371   , -10'sd353   }; /* W[ 496] =  0.7246  -0.6895i */
            10'h27D: dout <= { 10'sd369   , -10'sd355   }; /* W[ 500] =  0.7207  -0.6934i */
            10'h27E: dout <= { 10'sd366   , -10'sd358   }; /* W[ 504] =  0.7148  -0.6992i */
            10'h27F: dout <= { 10'sd364   , -10'sd360   }; /* W[ 508] =  0.7109  -0.7031i */
            10'h280: dout <= { 10'sd362   , -10'sd362   }; /* W[ 512] =  0.7070  -0.7070i */
            10'h281: dout <= { 10'sd360   , -10'sd364   }; /* W[ 516] =  0.7031  -0.7109i */
            10'h282: dout <= { 10'sd358   , -10'sd366   }; /* W[ 520] =  0.6992  -0.7148i */
            10'h283: dout <= { 10'sd355   , -10'sd369   }; /* W[ 524] =  0.6934  -0.7207i */
            10'h284: dout <= { 10'sd353   , -10'sd371   }; /* W[ 528] =  0.6895  -0.7246i */
            10'h285: dout <= { 10'sd351   , -10'sd373   }; /* W[ 532] =  0.6855  -0.7285i */
            10'h286: dout <= { 10'sd348   , -10'sd375   }; /* W[ 536] =  0.6797  -0.7324i */
            10'h287: dout <= { 10'sd346   , -10'sd377   }; /* W[ 540] =  0.6758  -0.7363i */
            10'h288: dout <= { 10'sd344   , -10'sd379   }; /* W[ 544] =  0.6719  -0.7402i */
            10'h289: dout <= { 10'sd342   , -10'sd381   }; /* W[ 548] =  0.6680  -0.7441i */
            10'h28A: dout <= { 10'sd339   , -10'sd384   }; /* W[ 552] =  0.6621  -0.7500i */
            10'h28B: dout <= { 10'sd337   , -10'sd386   }; /* W[ 556] =  0.6582  -0.7539i */
            10'h28C: dout <= { 10'sd334   , -10'sd388   }; /* W[ 560] =  0.6523  -0.7578i */
            10'h28D: dout <= { 10'sd332   , -10'sd390   }; /* W[ 564] =  0.6484  -0.7617i */
            10'h28E: dout <= { 10'sd330   , -10'sd392   }; /* W[ 568] =  0.6445  -0.7656i */
            10'h28F: dout <= { 10'sd327   , -10'sd394   }; /* W[ 572] =  0.6387  -0.7695i */
            10'h290: dout <= { 10'sd325   , -10'sd396   }; /* W[ 576] =  0.6348  -0.7734i */
            10'h291: dout <= { 10'sd322   , -10'sd398   }; /* W[ 580] =  0.6289  -0.7773i */
            10'h292: dout <= { 10'sd320   , -10'sd400   }; /* W[ 584] =  0.6250  -0.7812i */
            10'h293: dout <= { 10'sd317   , -10'sd402   }; /* W[ 588] =  0.6191  -0.7852i */
            10'h294: dout <= { 10'sd315   , -10'sd404   }; /* W[ 592] =  0.6152  -0.7891i */
            10'h295: dout <= { 10'sd313   , -10'sd406   }; /* W[ 596] =  0.6113  -0.7930i */
            10'h296: dout <= { 10'sd310   , -10'sd407   }; /* W[ 600] =  0.6055  -0.7949i */
            10'h297: dout <= { 10'sd308   , -10'sd409   }; /* W[ 604] =  0.6016  -0.7988i */
            10'h298: dout <= { 10'sd305   , -10'sd411   }; /* W[ 608] =  0.5957  -0.8027i */
            10'h299: dout <= { 10'sd302   , -10'sd413   }; /* W[ 612] =  0.5898  -0.8066i */
            10'h29A: dout <= { 10'sd300   , -10'sd415   }; /* W[ 616] =  0.5859  -0.8105i */
            10'h29B: dout <= { 10'sd297   , -10'sd417   }; /* W[ 620] =  0.5801  -0.8145i */
            10'h29C: dout <= { 10'sd295   , -10'sd419   }; /* W[ 624] =  0.5762  -0.8184i */
            10'h29D: dout <= { 10'sd292   , -10'sd420   }; /* W[ 628] =  0.5703  -0.8203i */
            10'h29E: dout <= { 10'sd290   , -10'sd422   }; /* W[ 632] =  0.5664  -0.8242i */
            10'h29F: dout <= { 10'sd287   , -10'sd424   }; /* W[ 636] =  0.5605  -0.8281i */
            10'h2A0: dout <= { 10'sd284   , -10'sd426   }; /* W[ 640] =  0.5547  -0.8320i */
            10'h2A1: dout <= { 10'sd282   , -10'sd427   }; /* W[ 644] =  0.5508  -0.8340i */
            10'h2A2: dout <= { 10'sd279   , -10'sd429   }; /* W[ 648] =  0.5449  -0.8379i */
            10'h2A3: dout <= { 10'sd277   , -10'sd431   }; /* W[ 652] =  0.5410  -0.8418i */
            10'h2A4: dout <= { 10'sd274   , -10'sd433   }; /* W[ 656] =  0.5352  -0.8457i */
            10'h2A5: dout <= { 10'sd271   , -10'sd434   }; /* W[ 660] =  0.5293  -0.8477i */
            10'h2A6: dout <= { 10'sd269   , -10'sd436   }; /* W[ 664] =  0.5254  -0.8516i */
            10'h2A7: dout <= { 10'sd266   , -10'sd438   }; /* W[ 668] =  0.5195  -0.8555i */
            10'h2A8: dout <= { 10'sd263   , -10'sd439   }; /* W[ 672] =  0.5137  -0.8574i */
            10'h2A9: dout <= { 10'sd261   , -10'sd441   }; /* W[ 676] =  0.5098  -0.8613i */
            10'h2AA: dout <= { 10'sd258   , -10'sd442   }; /* W[ 680] =  0.5039  -0.8633i */
            10'h2AB: dout <= { 10'sd255   , -10'sd444   }; /* W[ 684] =  0.4980  -0.8672i */
            10'h2AC: dout <= { 10'sd252   , -10'sd445   }; /* W[ 688] =  0.4922  -0.8691i */
            10'h2AD: dout <= { 10'sd250   , -10'sd447   }; /* W[ 692] =  0.4883  -0.8730i */
            10'h2AE: dout <= { 10'sd247   , -10'sd449   }; /* W[ 696] =  0.4824  -0.8770i */
            10'h2AF: dout <= { 10'sd244   , -10'sd450   }; /* W[ 700] =  0.4766  -0.8789i */
            10'h2B0: dout <= { 10'sd241   , -10'sd452   }; /* W[ 704] =  0.4707  -0.8828i */
            10'h2B1: dout <= { 10'sd239   , -10'sd453   }; /* W[ 708] =  0.4668  -0.8848i */
            10'h2B2: dout <= { 10'sd236   , -10'sd454   }; /* W[ 712] =  0.4609  -0.8867i */
            10'h2B3: dout <= { 10'sd233   , -10'sd456   }; /* W[ 716] =  0.4551  -0.8906i */
            10'h2B4: dout <= { 10'sd230   , -10'sd457   }; /* W[ 720] =  0.4492  -0.8926i */
            10'h2B5: dout <= { 10'sd227   , -10'sd459   }; /* W[ 724] =  0.4434  -0.8965i */
            10'h2B6: dout <= { 10'sd225   , -10'sd460   }; /* W[ 728] =  0.4395  -0.8984i */
            10'h2B7: dout <= { 10'sd222   , -10'sd461   }; /* W[ 732] =  0.4336  -0.9004i */
            10'h2B8: dout <= { 10'sd219   , -10'sd463   }; /* W[ 736] =  0.4277  -0.9043i */
            10'h2B9: dout <= { 10'sd216   , -10'sd464   }; /* W[ 740] =  0.4219  -0.9062i */
            10'h2BA: dout <= { 10'sd213   , -10'sd465   }; /* W[ 744] =  0.4160  -0.9082i */
            10'h2BB: dout <= { 10'sd210   , -10'sd467   }; /* W[ 748] =  0.4102  -0.9121i */
            10'h2BC: dout <= { 10'sd207   , -10'sd468   }; /* W[ 752] =  0.4043  -0.9141i */
            10'h2BD: dout <= { 10'sd205   , -10'sd469   }; /* W[ 756] =  0.4004  -0.9160i */
            10'h2BE: dout <= { 10'sd202   , -10'sd471   }; /* W[ 760] =  0.3945  -0.9199i */
            10'h2BF: dout <= { 10'sd199   , -10'sd472   }; /* W[ 764] =  0.3887  -0.9219i */
            10'h2C0: dout <= { 10'sd196   , -10'sd473   }; /* W[ 768] =  0.3828  -0.9238i */
            10'h2C1: dout <= { 10'sd193   , -10'sd474   }; /* W[ 772] =  0.3770  -0.9258i */
            10'h2C2: dout <= { 10'sd190   , -10'sd475   }; /* W[ 776] =  0.3711  -0.9277i */
            10'h2C3: dout <= { 10'sd187   , -10'sd477   }; /* W[ 780] =  0.3652  -0.9316i */
            10'h2C4: dout <= { 10'sd184   , -10'sd478   }; /* W[ 784] =  0.3594  -0.9336i */
            10'h2C5: dout <= { 10'sd181   , -10'sd479   }; /* W[ 788] =  0.3535  -0.9355i */
            10'h2C6: dout <= { 10'sd178   , -10'sd480   }; /* W[ 792] =  0.3477  -0.9375i */
            10'h2C7: dout <= { 10'sd175   , -10'sd481   }; /* W[ 796] =  0.3418  -0.9395i */
            10'h2C8: dout <= { 10'sd172   , -10'sd482   }; /* W[ 800] =  0.3359  -0.9414i */
            10'h2C9: dout <= { 10'sd170   , -10'sd483   }; /* W[ 804] =  0.3320  -0.9434i */
            10'h2CA: dout <= { 10'sd167   , -10'sd484   }; /* W[ 808] =  0.3262  -0.9453i */
            10'h2CB: dout <= { 10'sd164   , -10'sd485   }; /* W[ 812] =  0.3203  -0.9473i */
            10'h2CC: dout <= { 10'sd161   , -10'sd486   }; /* W[ 816] =  0.3145  -0.9492i */
            10'h2CD: dout <= { 10'sd158   , -10'sd487   }; /* W[ 820] =  0.3086  -0.9512i */
            10'h2CE: dout <= { 10'sd155   , -10'sd488   }; /* W[ 824] =  0.3027  -0.9531i */
            10'h2CF: dout <= { 10'sd152   , -10'sd489   }; /* W[ 828] =  0.2969  -0.9551i */
            10'h2D0: dout <= { 10'sd149   , -10'sd490   }; /* W[ 832] =  0.2910  -0.9570i */
            10'h2D1: dout <= { 10'sd146   , -10'sd491   }; /* W[ 836] =  0.2852  -0.9590i */
            10'h2D2: dout <= { 10'sd143   , -10'sd492   }; /* W[ 840] =  0.2793  -0.9609i */
            10'h2D3: dout <= { 10'sd140   , -10'sd493   }; /* W[ 844] =  0.2734  -0.9629i */
            10'h2D4: dout <= { 10'sd137   , -10'sd493   }; /* W[ 848] =  0.2676  -0.9629i */
            10'h2D5: dout <= { 10'sd134   , -10'sd494   }; /* W[ 852] =  0.2617  -0.9648i */
            10'h2D6: dout <= { 10'sd130   , -10'sd495   }; /* W[ 856] =  0.2539  -0.9668i */
            10'h2D7: dout <= { 10'sd127   , -10'sd496   }; /* W[ 860] =  0.2480  -0.9688i */
            10'h2D8: dout <= { 10'sd124   , -10'sd497   }; /* W[ 864] =  0.2422  -0.9707i */
            10'h2D9: dout <= { 10'sd121   , -10'sd497   }; /* W[ 868] =  0.2363  -0.9707i */
            10'h2DA: dout <= { 10'sd118   , -10'sd498   }; /* W[ 872] =  0.2305  -0.9727i */
            10'h2DB: dout <= { 10'sd115   , -10'sd499   }; /* W[ 876] =  0.2246  -0.9746i */
            10'h2DC: dout <= { 10'sd112   , -10'sd500   }; /* W[ 880] =  0.2188  -0.9766i */
            10'h2DD: dout <= { 10'sd109   , -10'sd500   }; /* W[ 884] =  0.2129  -0.9766i */
            10'h2DE: dout <= { 10'sd106   , -10'sd501   }; /* W[ 888] =  0.2070  -0.9785i */
            10'h2DF: dout <= { 10'sd103   , -10'sd502   }; /* W[ 892] =  0.2012  -0.9805i */
            10'h2E0: dout <= { 10'sd100   , -10'sd502   }; /* W[ 896] =  0.1953  -0.9805i */
            10'h2E1: dout <= { 10'sd97    , -10'sd503   }; /* W[ 900] =  0.1895  -0.9824i */
            10'h2E2: dout <= { 10'sd94    , -10'sd503   }; /* W[ 904] =  0.1836  -0.9824i */
            10'h2E3: dout <= { 10'sd91    , -10'sd504   }; /* W[ 908] =  0.1777  -0.9844i */
            10'h2E4: dout <= { 10'sd88    , -10'sd504   }; /* W[ 912] =  0.1719  -0.9844i */
            10'h2E5: dout <= { 10'sd84    , -10'sd505   }; /* W[ 916] =  0.1641  -0.9863i */
            10'h2E6: dout <= { 10'sd81    , -10'sd505   }; /* W[ 920] =  0.1582  -0.9863i */
            10'h2E7: dout <= { 10'sd78    , -10'sd506   }; /* W[ 924] =  0.1523  -0.9883i */
            10'h2E8: dout <= { 10'sd75    , -10'sd506   }; /* W[ 928] =  0.1465  -0.9883i */
            10'h2E9: dout <= { 10'sd72    , -10'sd507   }; /* W[ 932] =  0.1406  -0.9902i */
            10'h2EA: dout <= { 10'sd69    , -10'sd507   }; /* W[ 936] =  0.1348  -0.9902i */
            10'h2EB: dout <= { 10'sd66    , -10'sd508   }; /* W[ 940] =  0.1289  -0.9922i */
            10'h2EC: dout <= { 10'sd63    , -10'sd508   }; /* W[ 944] =  0.1230  -0.9922i */
            10'h2ED: dout <= { 10'sd60    , -10'sd509   }; /* W[ 948] =  0.1172  -0.9941i */
            10'h2EE: dout <= { 10'sd56    , -10'sd509   }; /* W[ 952] =  0.1094  -0.9941i */
            10'h2EF: dout <= { 10'sd53    , -10'sd509   }; /* W[ 956] =  0.1035  -0.9941i */
            10'h2F0: dout <= { 10'sd50    , -10'sd510   }; /* W[ 960] =  0.0977  -0.9961i */
            10'h2F1: dout <= { 10'sd47    , -10'sd510   }; /* W[ 964] =  0.0918  -0.9961i */
            10'h2F2: dout <= { 10'sd44    , -10'sd510   }; /* W[ 968] =  0.0859  -0.9961i */
            10'h2F3: dout <= { 10'sd41    , -10'sd510   }; /* W[ 972] =  0.0801  -0.9961i */
            10'h2F4: dout <= { 10'sd38    , -10'sd511   }; /* W[ 976] =  0.0742  -0.9980i */
            10'h2F5: dout <= { 10'sd35    , -10'sd511   }; /* W[ 980] =  0.0684  -0.9980i */
            10'h2F6: dout <= { 10'sd31    , -10'sd511   }; /* W[ 984] =  0.0605  -0.9980i */
            10'h2F7: dout <= { 10'sd28    , -10'sd511   }; /* W[ 988] =  0.0547  -0.9980i */
            10'h2F8: dout <= { 10'sd25    , -10'sd511   }; /* W[ 992] =  0.0488  -0.9980i */
            10'h2F9: dout <= { 10'sd22    , -10'sd512   }; /* W[ 996] =  0.0430  -1.0000i */
            10'h2FA: dout <= { 10'sd19    , -10'sd512   }; /* W[1000] =  0.0371  -1.0000i */
            10'h2FB: dout <= { 10'sd16    , -10'sd512   }; /* W[1004] =  0.0312  -1.0000i */
            10'h2FC: dout <= { 10'sd13    , -10'sd512   }; /* W[1008] =  0.0254  -1.0000i */
            10'h2FD: dout <= { 10'sd9     , -10'sd512   }; /* W[1012] =  0.0176  -1.0000i */
            10'h2FE: dout <= { 10'sd6     , -10'sd512   }; /* W[1016] =  0.0117  -1.0000i */
            10'h2FF: dout <= { 10'sd3     , -10'sd512   }; /* W[1020] =  0.0059  -1.0000i */
            10'h300: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            10'h301: dout <= { 10'sd511   , -10'sd9     }; /* W[  12] =  0.9980  -0.0176i */
            10'h302: dout <= { 10'sd511   , -10'sd19    }; /* W[  24] =  0.9980  -0.0371i */
            10'h303: dout <= { 10'sd511   , -10'sd28    }; /* W[  36] =  0.9980  -0.0547i */
            10'h304: dout <= { 10'sd511   , -10'sd38    }; /* W[  48] =  0.9980  -0.0742i */
            10'h305: dout <= { 10'sd510   , -10'sd47    }; /* W[  60] =  0.9961  -0.0918i */
            10'h306: dout <= { 10'sd509   , -10'sd56    }; /* W[  72] =  0.9941  -0.1094i */
            10'h307: dout <= { 10'sd508   , -10'sd66    }; /* W[  84] =  0.9922  -0.1289i */
            10'h308: dout <= { 10'sd506   , -10'sd75    }; /* W[  96] =  0.9883  -0.1465i */
            10'h309: dout <= { 10'sd505   , -10'sd84    }; /* W[ 108] =  0.9863  -0.1641i */
            10'h30A: dout <= { 10'sd503   , -10'sd94    }; /* W[ 120] =  0.9824  -0.1836i */
            10'h30B: dout <= { 10'sd502   , -10'sd103   }; /* W[ 132] =  0.9805  -0.2012i */
            10'h30C: dout <= { 10'sd500   , -10'sd112   }; /* W[ 144] =  0.9766  -0.2188i */
            10'h30D: dout <= { 10'sd497   , -10'sd121   }; /* W[ 156] =  0.9707  -0.2363i */
            10'h30E: dout <= { 10'sd495   , -10'sd130   }; /* W[ 168] =  0.9668  -0.2539i */
            10'h30F: dout <= { 10'sd493   , -10'sd140   }; /* W[ 180] =  0.9629  -0.2734i */
            10'h310: dout <= { 10'sd490   , -10'sd149   }; /* W[ 192] =  0.9570  -0.2910i */
            10'h311: dout <= { 10'sd487   , -10'sd158   }; /* W[ 204] =  0.9512  -0.3086i */
            10'h312: dout <= { 10'sd484   , -10'sd167   }; /* W[ 216] =  0.9453  -0.3262i */
            10'h313: dout <= { 10'sd481   , -10'sd175   }; /* W[ 228] =  0.9395  -0.3418i */
            10'h314: dout <= { 10'sd478   , -10'sd184   }; /* W[ 240] =  0.9336  -0.3594i */
            10'h315: dout <= { 10'sd474   , -10'sd193   }; /* W[ 252] =  0.9258  -0.3770i */
            10'h316: dout <= { 10'sd471   , -10'sd202   }; /* W[ 264] =  0.9199  -0.3945i */
            10'h317: dout <= { 10'sd467   , -10'sd210   }; /* W[ 276] =  0.9121  -0.4102i */
            10'h318: dout <= { 10'sd463   , -10'sd219   }; /* W[ 288] =  0.9043  -0.4277i */
            10'h319: dout <= { 10'sd459   , -10'sd227   }; /* W[ 300] =  0.8965  -0.4434i */
            10'h31A: dout <= { 10'sd454   , -10'sd236   }; /* W[ 312] =  0.8867  -0.4609i */
            10'h31B: dout <= { 10'sd450   , -10'sd244   }; /* W[ 324] =  0.8789  -0.4766i */
            10'h31C: dout <= { 10'sd445   , -10'sd252   }; /* W[ 336] =  0.8691  -0.4922i */
            10'h31D: dout <= { 10'sd441   , -10'sd261   }; /* W[ 348] =  0.8613  -0.5098i */
            10'h31E: dout <= { 10'sd436   , -10'sd269   }; /* W[ 360] =  0.8516  -0.5254i */
            10'h31F: dout <= { 10'sd431   , -10'sd277   }; /* W[ 372] =  0.8418  -0.5410i */
            10'h320: dout <= { 10'sd426   , -10'sd284   }; /* W[ 384] =  0.8320  -0.5547i */
            10'h321: dout <= { 10'sd420   , -10'sd292   }; /* W[ 396] =  0.8203  -0.5703i */
            10'h322: dout <= { 10'sd415   , -10'sd300   }; /* W[ 408] =  0.8105  -0.5859i */
            10'h323: dout <= { 10'sd409   , -10'sd308   }; /* W[ 420] =  0.7988  -0.6016i */
            10'h324: dout <= { 10'sd404   , -10'sd315   }; /* W[ 432] =  0.7891  -0.6152i */
            10'h325: dout <= { 10'sd398   , -10'sd322   }; /* W[ 444] =  0.7773  -0.6289i */
            10'h326: dout <= { 10'sd392   , -10'sd330   }; /* W[ 456] =  0.7656  -0.6445i */
            10'h327: dout <= { 10'sd386   , -10'sd337   }; /* W[ 468] =  0.7539  -0.6582i */
            10'h328: dout <= { 10'sd379   , -10'sd344   }; /* W[ 480] =  0.7402  -0.6719i */
            10'h329: dout <= { 10'sd373   , -10'sd351   }; /* W[ 492] =  0.7285  -0.6855i */
            10'h32A: dout <= { 10'sd366   , -10'sd358   }; /* W[ 504] =  0.7148  -0.6992i */
            10'h32B: dout <= { 10'sd360   , -10'sd364   }; /* W[ 516] =  0.7031  -0.7109i */
            10'h32C: dout <= { 10'sd353   , -10'sd371   }; /* W[ 528] =  0.6895  -0.7246i */
            10'h32D: dout <= { 10'sd346   , -10'sd377   }; /* W[ 540] =  0.6758  -0.7363i */
            10'h32E: dout <= { 10'sd339   , -10'sd384   }; /* W[ 552] =  0.6621  -0.7500i */
            10'h32F: dout <= { 10'sd332   , -10'sd390   }; /* W[ 564] =  0.6484  -0.7617i */
            10'h330: dout <= { 10'sd325   , -10'sd396   }; /* W[ 576] =  0.6348  -0.7734i */
            10'h331: dout <= { 10'sd317   , -10'sd402   }; /* W[ 588] =  0.6191  -0.7852i */
            10'h332: dout <= { 10'sd310   , -10'sd407   }; /* W[ 600] =  0.6055  -0.7949i */
            10'h333: dout <= { 10'sd302   , -10'sd413   }; /* W[ 612] =  0.5898  -0.8066i */
            10'h334: dout <= { 10'sd295   , -10'sd419   }; /* W[ 624] =  0.5762  -0.8184i */
            10'h335: dout <= { 10'sd287   , -10'sd424   }; /* W[ 636] =  0.5605  -0.8281i */
            10'h336: dout <= { 10'sd279   , -10'sd429   }; /* W[ 648] =  0.5449  -0.8379i */
            10'h337: dout <= { 10'sd271   , -10'sd434   }; /* W[ 660] =  0.5293  -0.8477i */
            10'h338: dout <= { 10'sd263   , -10'sd439   }; /* W[ 672] =  0.5137  -0.8574i */
            10'h339: dout <= { 10'sd255   , -10'sd444   }; /* W[ 684] =  0.4980  -0.8672i */
            10'h33A: dout <= { 10'sd247   , -10'sd449   }; /* W[ 696] =  0.4824  -0.8770i */
            10'h33B: dout <= { 10'sd239   , -10'sd453   }; /* W[ 708] =  0.4668  -0.8848i */
            10'h33C: dout <= { 10'sd230   , -10'sd457   }; /* W[ 720] =  0.4492  -0.8926i */
            10'h33D: dout <= { 10'sd222   , -10'sd461   }; /* W[ 732] =  0.4336  -0.9004i */
            10'h33E: dout <= { 10'sd213   , -10'sd465   }; /* W[ 744] =  0.4160  -0.9082i */
            10'h33F: dout <= { 10'sd205   , -10'sd469   }; /* W[ 756] =  0.4004  -0.9160i */
            10'h340: dout <= { 10'sd196   , -10'sd473   }; /* W[ 768] =  0.3828  -0.9238i */
            10'h341: dout <= { 10'sd187   , -10'sd477   }; /* W[ 780] =  0.3652  -0.9316i */
            10'h342: dout <= { 10'sd178   , -10'sd480   }; /* W[ 792] =  0.3477  -0.9375i */
            10'h343: dout <= { 10'sd170   , -10'sd483   }; /* W[ 804] =  0.3320  -0.9434i */
            10'h344: dout <= { 10'sd161   , -10'sd486   }; /* W[ 816] =  0.3145  -0.9492i */
            10'h345: dout <= { 10'sd152   , -10'sd489   }; /* W[ 828] =  0.2969  -0.9551i */
            10'h346: dout <= { 10'sd143   , -10'sd492   }; /* W[ 840] =  0.2793  -0.9609i */
            10'h347: dout <= { 10'sd134   , -10'sd494   }; /* W[ 852] =  0.2617  -0.9648i */
            10'h348: dout <= { 10'sd124   , -10'sd497   }; /* W[ 864] =  0.2422  -0.9707i */
            10'h349: dout <= { 10'sd115   , -10'sd499   }; /* W[ 876] =  0.2246  -0.9746i */
            10'h34A: dout <= { 10'sd106   , -10'sd501   }; /* W[ 888] =  0.2070  -0.9785i */
            10'h34B: dout <= { 10'sd97    , -10'sd503   }; /* W[ 900] =  0.1895  -0.9824i */
            10'h34C: dout <= { 10'sd88    , -10'sd504   }; /* W[ 912] =  0.1719  -0.9844i */
            10'h34D: dout <= { 10'sd78    , -10'sd506   }; /* W[ 924] =  0.1523  -0.9883i */
            10'h34E: dout <= { 10'sd69    , -10'sd507   }; /* W[ 936] =  0.1348  -0.9902i */
            10'h34F: dout <= { 10'sd60    , -10'sd509   }; /* W[ 948] =  0.1172  -0.9941i */
            10'h350: dout <= { 10'sd50    , -10'sd510   }; /* W[ 960] =  0.0977  -0.9961i */
            10'h351: dout <= { 10'sd41    , -10'sd510   }; /* W[ 972] =  0.0801  -0.9961i */
            10'h352: dout <= { 10'sd31    , -10'sd511   }; /* W[ 984] =  0.0605  -0.9980i */
            10'h353: dout <= { 10'sd22    , -10'sd512   }; /* W[ 996] =  0.0430  -1.0000i */
            10'h354: dout <= { 10'sd13    , -10'sd512   }; /* W[1008] =  0.0254  -1.0000i */
            10'h355: dout <= { 10'sd3     , -10'sd512   }; /* W[1020] =  0.0059  -1.0000i */
            10'h356: dout <= {-10'sd6     , -10'sd512   }; /* W[1032] = -0.0117  -1.0000i */
            10'h357: dout <= {-10'sd16    , -10'sd512   }; /* W[1044] = -0.0312  -1.0000i */
            10'h358: dout <= {-10'sd25    , -10'sd511   }; /* W[1056] = -0.0488  -0.9980i */
            10'h359: dout <= {-10'sd35    , -10'sd511   }; /* W[1068] = -0.0684  -0.9980i */
            10'h35A: dout <= {-10'sd44    , -10'sd510   }; /* W[1080] = -0.0859  -0.9961i */
            10'h35B: dout <= {-10'sd53    , -10'sd509   }; /* W[1092] = -0.1035  -0.9941i */
            10'h35C: dout <= {-10'sd63    , -10'sd508   }; /* W[1104] = -0.1230  -0.9922i */
            10'h35D: dout <= {-10'sd72    , -10'sd507   }; /* W[1116] = -0.1406  -0.9902i */
            10'h35E: dout <= {-10'sd81    , -10'sd505   }; /* W[1128] = -0.1582  -0.9863i */
            10'h35F: dout <= {-10'sd91    , -10'sd504   }; /* W[1140] = -0.1777  -0.9844i */
            10'h360: dout <= {-10'sd100   , -10'sd502   }; /* W[1152] = -0.1953  -0.9805i */
            10'h361: dout <= {-10'sd109   , -10'sd500   }; /* W[1164] = -0.2129  -0.9766i */
            10'h362: dout <= {-10'sd118   , -10'sd498   }; /* W[1176] = -0.2305  -0.9727i */
            10'h363: dout <= {-10'sd127   , -10'sd496   }; /* W[1188] = -0.2480  -0.9688i */
            10'h364: dout <= {-10'sd137   , -10'sd493   }; /* W[1200] = -0.2676  -0.9629i */
            10'h365: dout <= {-10'sd146   , -10'sd491   }; /* W[1212] = -0.2852  -0.9590i */
            10'h366: dout <= {-10'sd155   , -10'sd488   }; /* W[1224] = -0.3027  -0.9531i */
            10'h367: dout <= {-10'sd164   , -10'sd485   }; /* W[1236] = -0.3203  -0.9473i */
            10'h368: dout <= {-10'sd172   , -10'sd482   }; /* W[1248] = -0.3359  -0.9414i */
            10'h369: dout <= {-10'sd181   , -10'sd479   }; /* W[1260] = -0.3535  -0.9355i */
            10'h36A: dout <= {-10'sd190   , -10'sd475   }; /* W[1272] = -0.3711  -0.9277i */
            10'h36B: dout <= {-10'sd199   , -10'sd472   }; /* W[1284] = -0.3887  -0.9219i */
            10'h36C: dout <= {-10'sd207   , -10'sd468   }; /* W[1296] = -0.4043  -0.9141i */
            10'h36D: dout <= {-10'sd216   , -10'sd464   }; /* W[1308] = -0.4219  -0.9062i */
            10'h36E: dout <= {-10'sd225   , -10'sd460   }; /* W[1320] = -0.4395  -0.8984i */
            10'h36F: dout <= {-10'sd233   , -10'sd456   }; /* W[1332] = -0.4551  -0.8906i */
            10'h370: dout <= {-10'sd241   , -10'sd452   }; /* W[1344] = -0.4707  -0.8828i */
            10'h371: dout <= {-10'sd250   , -10'sd447   }; /* W[1356] = -0.4883  -0.8730i */
            10'h372: dout <= {-10'sd258   , -10'sd442   }; /* W[1368] = -0.5039  -0.8633i */
            10'h373: dout <= {-10'sd266   , -10'sd438   }; /* W[1380] = -0.5195  -0.8555i */
            10'h374: dout <= {-10'sd274   , -10'sd433   }; /* W[1392] = -0.5352  -0.8457i */
            10'h375: dout <= {-10'sd282   , -10'sd427   }; /* W[1404] = -0.5508  -0.8340i */
            10'h376: dout <= {-10'sd290   , -10'sd422   }; /* W[1416] = -0.5664  -0.8242i */
            10'h377: dout <= {-10'sd297   , -10'sd417   }; /* W[1428] = -0.5801  -0.8145i */
            10'h378: dout <= {-10'sd305   , -10'sd411   }; /* W[1440] = -0.5957  -0.8027i */
            10'h379: dout <= {-10'sd313   , -10'sd406   }; /* W[1452] = -0.6113  -0.7930i */
            10'h37A: dout <= {-10'sd320   , -10'sd400   }; /* W[1464] = -0.6250  -0.7812i */
            10'h37B: dout <= {-10'sd327   , -10'sd394   }; /* W[1476] = -0.6387  -0.7695i */
            10'h37C: dout <= {-10'sd334   , -10'sd388   }; /* W[1488] = -0.6523  -0.7578i */
            10'h37D: dout <= {-10'sd342   , -10'sd381   }; /* W[1500] = -0.6680  -0.7441i */
            10'h37E: dout <= {-10'sd348   , -10'sd375   }; /* W[1512] = -0.6797  -0.7324i */
            10'h37F: dout <= {-10'sd355   , -10'sd369   }; /* W[1524] = -0.6934  -0.7207i */
            10'h380: dout <= {-10'sd362   , -10'sd362   }; /* W[1536] = -0.7070  -0.7070i */
            10'h381: dout <= {-10'sd369   , -10'sd355   }; /* W[1548] = -0.7207  -0.6934i */
            10'h382: dout <= {-10'sd375   , -10'sd348   }; /* W[1560] = -0.7324  -0.6797i */
            10'h383: dout <= {-10'sd381   , -10'sd342   }; /* W[1572] = -0.7441  -0.6680i */
            10'h384: dout <= {-10'sd388   , -10'sd334   }; /* W[1584] = -0.7578  -0.6523i */
            10'h385: dout <= {-10'sd394   , -10'sd327   }; /* W[1596] = -0.7695  -0.6387i */
            10'h386: dout <= {-10'sd400   , -10'sd320   }; /* W[1608] = -0.7812  -0.6250i */
            10'h387: dout <= {-10'sd406   , -10'sd313   }; /* W[1620] = -0.7930  -0.6113i */
            10'h388: dout <= {-10'sd411   , -10'sd305   }; /* W[1632] = -0.8027  -0.5957i */
            10'h389: dout <= {-10'sd417   , -10'sd297   }; /* W[1644] = -0.8145  -0.5801i */
            10'h38A: dout <= {-10'sd422   , -10'sd290   }; /* W[1656] = -0.8242  -0.5664i */
            10'h38B: dout <= {-10'sd427   , -10'sd282   }; /* W[1668] = -0.8340  -0.5508i */
            10'h38C: dout <= {-10'sd433   , -10'sd274   }; /* W[1680] = -0.8457  -0.5352i */
            10'h38D: dout <= {-10'sd438   , -10'sd266   }; /* W[1692] = -0.8555  -0.5195i */
            10'h38E: dout <= {-10'sd442   , -10'sd258   }; /* W[1704] = -0.8633  -0.5039i */
            10'h38F: dout <= {-10'sd447   , -10'sd250   }; /* W[1716] = -0.8730  -0.4883i */
            10'h390: dout <= {-10'sd452   , -10'sd241   }; /* W[1728] = -0.8828  -0.4707i */
            10'h391: dout <= {-10'sd456   , -10'sd233   }; /* W[1740] = -0.8906  -0.4551i */
            10'h392: dout <= {-10'sd460   , -10'sd225   }; /* W[1752] = -0.8984  -0.4395i */
            10'h393: dout <= {-10'sd464   , -10'sd216   }; /* W[1764] = -0.9062  -0.4219i */
            10'h394: dout <= {-10'sd468   , -10'sd207   }; /* W[1776] = -0.9141  -0.4043i */
            10'h395: dout <= {-10'sd472   , -10'sd199   }; /* W[1788] = -0.9219  -0.3887i */
            10'h396: dout <= {-10'sd475   , -10'sd190   }; /* W[1800] = -0.9277  -0.3711i */
            10'h397: dout <= {-10'sd479   , -10'sd181   }; /* W[1812] = -0.9355  -0.3535i */
            10'h398: dout <= {-10'sd482   , -10'sd172   }; /* W[1824] = -0.9414  -0.3359i */
            10'h399: dout <= {-10'sd485   , -10'sd164   }; /* W[1836] = -0.9473  -0.3203i */
            10'h39A: dout <= {-10'sd488   , -10'sd155   }; /* W[1848] = -0.9531  -0.3027i */
            10'h39B: dout <= {-10'sd491   , -10'sd146   }; /* W[1860] = -0.9590  -0.2852i */
            10'h39C: dout <= {-10'sd493   , -10'sd137   }; /* W[1872] = -0.9629  -0.2676i */
            10'h39D: dout <= {-10'sd496   , -10'sd127   }; /* W[1884] = -0.9688  -0.2480i */
            10'h39E: dout <= {-10'sd498   , -10'sd118   }; /* W[1896] = -0.9727  -0.2305i */
            10'h39F: dout <= {-10'sd500   , -10'sd109   }; /* W[1908] = -0.9766  -0.2129i */
            10'h3A0: dout <= {-10'sd502   , -10'sd100   }; /* W[1920] = -0.9805  -0.1953i */
            10'h3A1: dout <= {-10'sd504   , -10'sd91    }; /* W[1932] = -0.9844  -0.1777i */
            10'h3A2: dout <= {-10'sd505   , -10'sd81    }; /* W[1944] = -0.9863  -0.1582i */
            10'h3A3: dout <= {-10'sd507   , -10'sd72    }; /* W[1956] = -0.9902  -0.1406i */
            10'h3A4: dout <= {-10'sd508   , -10'sd63    }; /* W[1968] = -0.9922  -0.1230i */
            10'h3A5: dout <= {-10'sd509   , -10'sd53    }; /* W[1980] = -0.9941  -0.1035i */
            10'h3A6: dout <= {-10'sd510   , -10'sd44    }; /* W[1992] = -0.9961  -0.0859i */
            10'h3A7: dout <= {-10'sd511   , -10'sd35    }; /* W[2004] = -0.9980  -0.0684i */
            10'h3A8: dout <= {-10'sd511   , -10'sd25    }; /* W[2016] = -0.9980  -0.0488i */
            10'h3A9: dout <= {-10'sd512   , -10'sd16    }; /* W[2028] = -1.0000  -0.0312i */
            10'h3AA: dout <= {-10'sd512   , -10'sd6     }; /* W[2040] = -1.0000  -0.0117i */
            10'h3AB: dout <= {-10'sd512   ,  10'sd3     }; /* W[2052] = -1.0000   0.0059i */
            10'h3AC: dout <= {-10'sd512   ,  10'sd13    }; /* W[2064] = -1.0000   0.0254i */
            10'h3AD: dout <= {-10'sd512   ,  10'sd22    }; /* W[2076] = -1.0000   0.0430i */
            10'h3AE: dout <= {-10'sd511   ,  10'sd31    }; /* W[2088] = -0.9980   0.0605i */
            10'h3AF: dout <= {-10'sd510   ,  10'sd41    }; /* W[2100] = -0.9961   0.0801i */
            10'h3B0: dout <= {-10'sd510   ,  10'sd50    }; /* W[2112] = -0.9961   0.0977i */
            10'h3B1: dout <= {-10'sd509   ,  10'sd60    }; /* W[2124] = -0.9941   0.1172i */
            10'h3B2: dout <= {-10'sd507   ,  10'sd69    }; /* W[2136] = -0.9902   0.1348i */
            10'h3B3: dout <= {-10'sd506   ,  10'sd78    }; /* W[2148] = -0.9883   0.1523i */
            10'h3B4: dout <= {-10'sd504   ,  10'sd88    }; /* W[2160] = -0.9844   0.1719i */
            10'h3B5: dout <= {-10'sd503   ,  10'sd97    }; /* W[2172] = -0.9824   0.1895i */
            10'h3B6: dout <= {-10'sd501   ,  10'sd106   }; /* W[2184] = -0.9785   0.2070i */
            10'h3B7: dout <= {-10'sd499   ,  10'sd115   }; /* W[2196] = -0.9746   0.2246i */
            10'h3B8: dout <= {-10'sd497   ,  10'sd124   }; /* W[2208] = -0.9707   0.2422i */
            10'h3B9: dout <= {-10'sd494   ,  10'sd134   }; /* W[2220] = -0.9648   0.2617i */
            10'h3BA: dout <= {-10'sd492   ,  10'sd143   }; /* W[2232] = -0.9609   0.2793i */
            10'h3BB: dout <= {-10'sd489   ,  10'sd152   }; /* W[2244] = -0.9551   0.2969i */
            10'h3BC: dout <= {-10'sd486   ,  10'sd161   }; /* W[2256] = -0.9492   0.3145i */
            10'h3BD: dout <= {-10'sd483   ,  10'sd170   }; /* W[2268] = -0.9434   0.3320i */
            10'h3BE: dout <= {-10'sd480   ,  10'sd178   }; /* W[2280] = -0.9375   0.3477i */
            10'h3BF: dout <= {-10'sd477   ,  10'sd187   }; /* W[2292] = -0.9316   0.3652i */
            10'h3C0: dout <= {-10'sd473   ,  10'sd196   }; /* W[2304] = -0.9238   0.3828i */
            10'h3C1: dout <= {-10'sd469   ,  10'sd205   }; /* W[2316] = -0.9160   0.4004i */
            10'h3C2: dout <= {-10'sd465   ,  10'sd213   }; /* W[2328] = -0.9082   0.4160i */
            10'h3C3: dout <= {-10'sd461   ,  10'sd222   }; /* W[2340] = -0.9004   0.4336i */
            10'h3C4: dout <= {-10'sd457   ,  10'sd230   }; /* W[2352] = -0.8926   0.4492i */
            10'h3C5: dout <= {-10'sd453   ,  10'sd239   }; /* W[2364] = -0.8848   0.4668i */
            10'h3C6: dout <= {-10'sd449   ,  10'sd247   }; /* W[2376] = -0.8770   0.4824i */
            10'h3C7: dout <= {-10'sd444   ,  10'sd255   }; /* W[2388] = -0.8672   0.4980i */
            10'h3C8: dout <= {-10'sd439   ,  10'sd263   }; /* W[2400] = -0.8574   0.5137i */
            10'h3C9: dout <= {-10'sd434   ,  10'sd271   }; /* W[2412] = -0.8477   0.5293i */
            10'h3CA: dout <= {-10'sd429   ,  10'sd279   }; /* W[2424] = -0.8379   0.5449i */
            10'h3CB: dout <= {-10'sd424   ,  10'sd287   }; /* W[2436] = -0.8281   0.5605i */
            10'h3CC: dout <= {-10'sd419   ,  10'sd295   }; /* W[2448] = -0.8184   0.5762i */
            10'h3CD: dout <= {-10'sd413   ,  10'sd302   }; /* W[2460] = -0.8066   0.5898i */
            10'h3CE: dout <= {-10'sd407   ,  10'sd310   }; /* W[2472] = -0.7949   0.6055i */
            10'h3CF: dout <= {-10'sd402   ,  10'sd317   }; /* W[2484] = -0.7852   0.6191i */
            10'h3D0: dout <= {-10'sd396   ,  10'sd325   }; /* W[2496] = -0.7734   0.6348i */
            10'h3D1: dout <= {-10'sd390   ,  10'sd332   }; /* W[2508] = -0.7617   0.6484i */
            10'h3D2: dout <= {-10'sd384   ,  10'sd339   }; /* W[2520] = -0.7500   0.6621i */
            10'h3D3: dout <= {-10'sd377   ,  10'sd346   }; /* W[2532] = -0.7363   0.6758i */
            10'h3D4: dout <= {-10'sd371   ,  10'sd353   }; /* W[2544] = -0.7246   0.6895i */
            10'h3D5: dout <= {-10'sd364   ,  10'sd360   }; /* W[2556] = -0.7109   0.7031i */
            10'h3D6: dout <= {-10'sd358   ,  10'sd366   }; /* W[2568] = -0.6992   0.7148i */
            10'h3D7: dout <= {-10'sd351   ,  10'sd373   }; /* W[2580] = -0.6855   0.7285i */
            10'h3D8: dout <= {-10'sd344   ,  10'sd379   }; /* W[2592] = -0.6719   0.7402i */
            10'h3D9: dout <= {-10'sd337   ,  10'sd386   }; /* W[2604] = -0.6582   0.7539i */
            10'h3DA: dout <= {-10'sd330   ,  10'sd392   }; /* W[2616] = -0.6445   0.7656i */
            10'h3DB: dout <= {-10'sd322   ,  10'sd398   }; /* W[2628] = -0.6289   0.7773i */
            10'h3DC: dout <= {-10'sd315   ,  10'sd404   }; /* W[2640] = -0.6152   0.7891i */
            10'h3DD: dout <= {-10'sd308   ,  10'sd409   }; /* W[2652] = -0.6016   0.7988i */
            10'h3DE: dout <= {-10'sd300   ,  10'sd415   }; /* W[2664] = -0.5859   0.8105i */
            10'h3DF: dout <= {-10'sd292   ,  10'sd420   }; /* W[2676] = -0.5703   0.8203i */
            10'h3E0: dout <= {-10'sd284   ,  10'sd426   }; /* W[2688] = -0.5547   0.8320i */
            10'h3E1: dout <= {-10'sd277   ,  10'sd431   }; /* W[2700] = -0.5410   0.8418i */
            10'h3E2: dout <= {-10'sd269   ,  10'sd436   }; /* W[2712] = -0.5254   0.8516i */
            10'h3E3: dout <= {-10'sd261   ,  10'sd441   }; /* W[2724] = -0.5098   0.8613i */
            10'h3E4: dout <= {-10'sd252   ,  10'sd445   }; /* W[2736] = -0.4922   0.8691i */
            10'h3E5: dout <= {-10'sd244   ,  10'sd450   }; /* W[2748] = -0.4766   0.8789i */
            10'h3E6: dout <= {-10'sd236   ,  10'sd454   }; /* W[2760] = -0.4609   0.8867i */
            10'h3E7: dout <= {-10'sd227   ,  10'sd459   }; /* W[2772] = -0.4434   0.8965i */
            10'h3E8: dout <= {-10'sd219   ,  10'sd463   }; /* W[2784] = -0.4277   0.9043i */
            10'h3E9: dout <= {-10'sd210   ,  10'sd467   }; /* W[2796] = -0.4102   0.9121i */
            10'h3EA: dout <= {-10'sd202   ,  10'sd471   }; /* W[2808] = -0.3945   0.9199i */
            10'h3EB: dout <= {-10'sd193   ,  10'sd474   }; /* W[2820] = -0.3770   0.9258i */
            10'h3EC: dout <= {-10'sd184   ,  10'sd478   }; /* W[2832] = -0.3594   0.9336i */
            10'h3ED: dout <= {-10'sd175   ,  10'sd481   }; /* W[2844] = -0.3418   0.9395i */
            10'h3EE: dout <= {-10'sd167   ,  10'sd484   }; /* W[2856] = -0.3262   0.9453i */
            10'h3EF: dout <= {-10'sd158   ,  10'sd487   }; /* W[2868] = -0.3086   0.9512i */
            10'h3F0: dout <= {-10'sd149   ,  10'sd490   }; /* W[2880] = -0.2910   0.9570i */
            10'h3F1: dout <= {-10'sd140   ,  10'sd493   }; /* W[2892] = -0.2734   0.9629i */
            10'h3F2: dout <= {-10'sd130   ,  10'sd495   }; /* W[2904] = -0.2539   0.9668i */
            10'h3F3: dout <= {-10'sd121   ,  10'sd497   }; /* W[2916] = -0.2363   0.9707i */
            10'h3F4: dout <= {-10'sd112   ,  10'sd500   }; /* W[2928] = -0.2188   0.9766i */
            10'h3F5: dout <= {-10'sd103   ,  10'sd502   }; /* W[2940] = -0.2012   0.9805i */
            10'h3F6: dout <= {-10'sd94    ,  10'sd503   }; /* W[2952] = -0.1836   0.9824i */
            10'h3F7: dout <= {-10'sd84    ,  10'sd505   }; /* W[2964] = -0.1641   0.9863i */
            10'h3F8: dout <= {-10'sd75    ,  10'sd506   }; /* W[2976] = -0.1465   0.9883i */
            10'h3F9: dout <= {-10'sd66    ,  10'sd508   }; /* W[2988] = -0.1289   0.9922i */
            10'h3FA: dout <= {-10'sd56    ,  10'sd509   }; /* W[3000] = -0.1094   0.9941i */
            10'h3FB: dout <= {-10'sd47    ,  10'sd510   }; /* W[3012] = -0.0918   0.9961i */
            10'h3FC: dout <= {-10'sd38    ,  10'sd511   }; /* W[3024] = -0.0742   0.9980i */
            10'h3FD: dout <= {-10'sd28    ,  10'sd511   }; /* W[3036] = -0.0547   0.9980i */
            10'h3FE: dout <= {-10'sd19    ,  10'sd511   }; /* W[3048] = -0.0371   0.9980i */
            10'h3FF: dout <= {-10'sd9     ,  10'sd511   }; /* W[3060] = -0.0176   0.9980i */
            default:
              begin
                dout <= 20'd0;
              end
         endcase
      end
  end
endmodule

/** @} */ /* End of addtogroup ModMiscIpDspFftR22Sdc */
/* END OF FILE */
