/******************************************************************************
 * Copyright (c) 2010-2012, XIONLOGIC LIMITED                                 *
 * Copyright (c) 2010-2012, Niroshan Mahasinghe                               *
 * All rights reserved.                                                       *
 *                                                                            *
 * Redistribution and use in source and binary forms, with or without         *
 * modification, are permitted provided that the following conditions         *
 * are met:                                                                   *
 *                                                                            *
 *  o  Redistributions of source code must retain the above copyright         *
 *     notice, this list of conditions and the following disclaimer.          *
 *                                                                            *
 *  o  Redistributions in binary form must reproduce the above copyright      *
 *     notice, this list of conditions and the following disclaimer in        *
 *     the documentation and/or other materials provided with the             *
 *     distribution.                                                          *
 *                                                                            *
 *  o  Neither the name of XIONLOGIC LIMITED nor the names of its             *
 *     contributors may be used to endorse or promote products                *
 *     derived from this software without specific prior                      *
 *     written permission.                                                    *
 *                                                                            *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS        *
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED  *
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR *
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR          *
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,      *
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,        *
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR         *
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF     *
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING       *
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS         *
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.               *
 *****************************************************************************/

/*****************************************************************************
 *  Original Author(s):
 *      Niroshan Mahasinghe, nmahasinghe@xionlogic.com
 *****************************************************************************/
/** \file
 * \ingroup ModMiscIpDspFftR2Rom
 * Twiddle-factor ROM for 1024-point radix-2 FFT processors.
 * This file implements the twiddle-factor ROM for 1024-point radix-2 FFT
 * processors.
 */

/***************************************************************************
 * Include files
 ***************************************************************************/
`include "system.vh"

/***************************************************************************
 * Modules
 ***************************************************************************/
/** \addtogroup ModMiscIpDspFftR2Rom
 * @{
 */

/** Twiddle-factor ROM for 1024-point radix-2 FFT processors.
 * This module implements the twiddle-factor ROM for 1024-point radix-2 FFT
 * processors. It outputs the twiddle-factor, W<sup>nk</sup> for a given
 * \a nk one cycle later.
 *
 * \param[in]  clk      System clock.
 * \param[in]  rst_n    Active low asynchronous reset line.
 * \param[in]  addr     Twiddle-factor ROM address (i.e. \a nk) to read.
 * \param[in]  addr_vld Indicates that the read address is valid.
 * \param[out] tf_re    Twiddle-factor output (real part).
 * \param[out] tf_im    Twiddle-factor output (imaginary part).
 */
module fft_r2_rom_1024 (
    input  wire               clk,
    input  wire               rst_n,
    input  wire        [ 8:0] addr,
    input  wire               addr_vld,
    output wire signed [ 9:0] tf_re,
    output wire signed [ 9:0] tf_im
  );

  reg  [19:0] dout;

  assign tf_re = dout[19:10];
  assign tf_im = dout[9:0];

  initial
    begin
     `ifndef USE_RESET
      dout = 20'd0;
     `endif
    end

  always @ (posedge clk or negedge rst_n)
    begin
      if (!rst_n)
        begin
         `ifdef USE_RESET
          dout <= 20'd0;
         `endif
        end
      else if (addr_vld)
        begin
          case (addr)
            9'h000: dout <= { 10'sd511   ,  10'sd0     }; /* W[   0] =  0.9980   0.0000i */
            9'h001: dout <= { 10'sd511   , -10'sd3     }; /* W[   1] =  0.9980  -0.0059i */
            9'h002: dout <= { 10'sd511   , -10'sd6     }; /* W[   2] =  0.9980  -0.0117i */
            9'h003: dout <= { 10'sd511   , -10'sd9     }; /* W[   3] =  0.9980  -0.0176i */
            9'h004: dout <= { 10'sd511   , -10'sd13    }; /* W[   4] =  0.9980  -0.0254i */
            9'h005: dout <= { 10'sd511   , -10'sd16    }; /* W[   5] =  0.9980  -0.0312i */
            9'h006: dout <= { 10'sd511   , -10'sd19    }; /* W[   6] =  0.9980  -0.0371i */
            9'h007: dout <= { 10'sd511   , -10'sd22    }; /* W[   7] =  0.9980  -0.0430i */
            9'h008: dout <= { 10'sd511   , -10'sd25    }; /* W[   8] =  0.9980  -0.0488i */
            9'h009: dout <= { 10'sd511   , -10'sd28    }; /* W[   9] =  0.9980  -0.0547i */
            9'h00A: dout <= { 10'sd511   , -10'sd31    }; /* W[  10] =  0.9980  -0.0605i */
            9'h00B: dout <= { 10'sd511   , -10'sd35    }; /* W[  11] =  0.9980  -0.0684i */
            9'h00C: dout <= { 10'sd511   , -10'sd38    }; /* W[  12] =  0.9980  -0.0742i */
            9'h00D: dout <= { 10'sd510   , -10'sd41    }; /* W[  13] =  0.9961  -0.0801i */
            9'h00E: dout <= { 10'sd510   , -10'sd44    }; /* W[  14] =  0.9961  -0.0859i */
            9'h00F: dout <= { 10'sd510   , -10'sd47    }; /* W[  15] =  0.9961  -0.0918i */
            9'h010: dout <= { 10'sd510   , -10'sd50    }; /* W[  16] =  0.9961  -0.0977i */
            9'h011: dout <= { 10'sd509   , -10'sd53    }; /* W[  17] =  0.9941  -0.1035i */
            9'h012: dout <= { 10'sd509   , -10'sd56    }; /* W[  18] =  0.9941  -0.1094i */
            9'h013: dout <= { 10'sd509   , -10'sd60    }; /* W[  19] =  0.9941  -0.1172i */
            9'h014: dout <= { 10'sd508   , -10'sd63    }; /* W[  20] =  0.9922  -0.1230i */
            9'h015: dout <= { 10'sd508   , -10'sd66    }; /* W[  21] =  0.9922  -0.1289i */
            9'h016: dout <= { 10'sd507   , -10'sd69    }; /* W[  22] =  0.9902  -0.1348i */
            9'h017: dout <= { 10'sd507   , -10'sd72    }; /* W[  23] =  0.9902  -0.1406i */
            9'h018: dout <= { 10'sd506   , -10'sd75    }; /* W[  24] =  0.9883  -0.1465i */
            9'h019: dout <= { 10'sd506   , -10'sd78    }; /* W[  25] =  0.9883  -0.1523i */
            9'h01A: dout <= { 10'sd505   , -10'sd81    }; /* W[  26] =  0.9863  -0.1582i */
            9'h01B: dout <= { 10'sd505   , -10'sd84    }; /* W[  27] =  0.9863  -0.1641i */
            9'h01C: dout <= { 10'sd504   , -10'sd88    }; /* W[  28] =  0.9844  -0.1719i */
            9'h01D: dout <= { 10'sd504   , -10'sd91    }; /* W[  29] =  0.9844  -0.1777i */
            9'h01E: dout <= { 10'sd503   , -10'sd94    }; /* W[  30] =  0.9824  -0.1836i */
            9'h01F: dout <= { 10'sd503   , -10'sd97    }; /* W[  31] =  0.9824  -0.1895i */
            9'h020: dout <= { 10'sd502   , -10'sd100   }; /* W[  32] =  0.9805  -0.1953i */
            9'h021: dout <= { 10'sd502   , -10'sd103   }; /* W[  33] =  0.9805  -0.2012i */
            9'h022: dout <= { 10'sd501   , -10'sd106   }; /* W[  34] =  0.9785  -0.2070i */
            9'h023: dout <= { 10'sd500   , -10'sd109   }; /* W[  35] =  0.9766  -0.2129i */
            9'h024: dout <= { 10'sd500   , -10'sd112   }; /* W[  36] =  0.9766  -0.2188i */
            9'h025: dout <= { 10'sd499   , -10'sd115   }; /* W[  37] =  0.9746  -0.2246i */
            9'h026: dout <= { 10'sd498   , -10'sd118   }; /* W[  38] =  0.9727  -0.2305i */
            9'h027: dout <= { 10'sd497   , -10'sd121   }; /* W[  39] =  0.9707  -0.2363i */
            9'h028: dout <= { 10'sd497   , -10'sd124   }; /* W[  40] =  0.9707  -0.2422i */
            9'h029: dout <= { 10'sd496   , -10'sd127   }; /* W[  41] =  0.9688  -0.2480i */
            9'h02A: dout <= { 10'sd495   , -10'sd130   }; /* W[  42] =  0.9668  -0.2539i */
            9'h02B: dout <= { 10'sd494   , -10'sd134   }; /* W[  43] =  0.9648  -0.2617i */
            9'h02C: dout <= { 10'sd493   , -10'sd137   }; /* W[  44] =  0.9629  -0.2676i */
            9'h02D: dout <= { 10'sd493   , -10'sd140   }; /* W[  45] =  0.9629  -0.2734i */
            9'h02E: dout <= { 10'sd492   , -10'sd143   }; /* W[  46] =  0.9609  -0.2793i */
            9'h02F: dout <= { 10'sd491   , -10'sd146   }; /* W[  47] =  0.9590  -0.2852i */
            9'h030: dout <= { 10'sd490   , -10'sd149   }; /* W[  48] =  0.9570  -0.2910i */
            9'h031: dout <= { 10'sd489   , -10'sd152   }; /* W[  49] =  0.9551  -0.2969i */
            9'h032: dout <= { 10'sd488   , -10'sd155   }; /* W[  50] =  0.9531  -0.3027i */
            9'h033: dout <= { 10'sd487   , -10'sd158   }; /* W[  51] =  0.9512  -0.3086i */
            9'h034: dout <= { 10'sd486   , -10'sd161   }; /* W[  52] =  0.9492  -0.3145i */
            9'h035: dout <= { 10'sd485   , -10'sd164   }; /* W[  53] =  0.9473  -0.3203i */
            9'h036: dout <= { 10'sd484   , -10'sd167   }; /* W[  54] =  0.9453  -0.3262i */
            9'h037: dout <= { 10'sd483   , -10'sd170   }; /* W[  55] =  0.9434  -0.3320i */
            9'h038: dout <= { 10'sd482   , -10'sd172   }; /* W[  56] =  0.9414  -0.3359i */
            9'h039: dout <= { 10'sd481   , -10'sd175   }; /* W[  57] =  0.9395  -0.3418i */
            9'h03A: dout <= { 10'sd480   , -10'sd178   }; /* W[  58] =  0.9375  -0.3477i */
            9'h03B: dout <= { 10'sd479   , -10'sd181   }; /* W[  59] =  0.9355  -0.3535i */
            9'h03C: dout <= { 10'sd478   , -10'sd184   }; /* W[  60] =  0.9336  -0.3594i */
            9'h03D: dout <= { 10'sd477   , -10'sd187   }; /* W[  61] =  0.9316  -0.3652i */
            9'h03E: dout <= { 10'sd475   , -10'sd190   }; /* W[  62] =  0.9277  -0.3711i */
            9'h03F: dout <= { 10'sd474   , -10'sd193   }; /* W[  63] =  0.9258  -0.3770i */
            9'h040: dout <= { 10'sd473   , -10'sd196   }; /* W[  64] =  0.9238  -0.3828i */
            9'h041: dout <= { 10'sd472   , -10'sd199   }; /* W[  65] =  0.9219  -0.3887i */
            9'h042: dout <= { 10'sd471   , -10'sd202   }; /* W[  66] =  0.9199  -0.3945i */
            9'h043: dout <= { 10'sd469   , -10'sd205   }; /* W[  67] =  0.9160  -0.4004i */
            9'h044: dout <= { 10'sd468   , -10'sd207   }; /* W[  68] =  0.9141  -0.4043i */
            9'h045: dout <= { 10'sd467   , -10'sd210   }; /* W[  69] =  0.9121  -0.4102i */
            9'h046: dout <= { 10'sd465   , -10'sd213   }; /* W[  70] =  0.9082  -0.4160i */
            9'h047: dout <= { 10'sd464   , -10'sd216   }; /* W[  71] =  0.9062  -0.4219i */
            9'h048: dout <= { 10'sd463   , -10'sd219   }; /* W[  72] =  0.9043  -0.4277i */
            9'h049: dout <= { 10'sd461   , -10'sd222   }; /* W[  73] =  0.9004  -0.4336i */
            9'h04A: dout <= { 10'sd460   , -10'sd225   }; /* W[  74] =  0.8984  -0.4395i */
            9'h04B: dout <= { 10'sd459   , -10'sd227   }; /* W[  75] =  0.8965  -0.4434i */
            9'h04C: dout <= { 10'sd457   , -10'sd230   }; /* W[  76] =  0.8926  -0.4492i */
            9'h04D: dout <= { 10'sd456   , -10'sd233   }; /* W[  77] =  0.8906  -0.4551i */
            9'h04E: dout <= { 10'sd454   , -10'sd236   }; /* W[  78] =  0.8867  -0.4609i */
            9'h04F: dout <= { 10'sd453   , -10'sd239   }; /* W[  79] =  0.8848  -0.4668i */
            9'h050: dout <= { 10'sd452   , -10'sd241   }; /* W[  80] =  0.8828  -0.4707i */
            9'h051: dout <= { 10'sd450   , -10'sd244   }; /* W[  81] =  0.8789  -0.4766i */
            9'h052: dout <= { 10'sd449   , -10'sd247   }; /* W[  82] =  0.8770  -0.4824i */
            9'h053: dout <= { 10'sd447   , -10'sd250   }; /* W[  83] =  0.8730  -0.4883i */
            9'h054: dout <= { 10'sd445   , -10'sd252   }; /* W[  84] =  0.8691  -0.4922i */
            9'h055: dout <= { 10'sd444   , -10'sd255   }; /* W[  85] =  0.8672  -0.4980i */
            9'h056: dout <= { 10'sd442   , -10'sd258   }; /* W[  86] =  0.8633  -0.5039i */
            9'h057: dout <= { 10'sd441   , -10'sd261   }; /* W[  87] =  0.8613  -0.5098i */
            9'h058: dout <= { 10'sd439   , -10'sd263   }; /* W[  88] =  0.8574  -0.5137i */
            9'h059: dout <= { 10'sd438   , -10'sd266   }; /* W[  89] =  0.8555  -0.5195i */
            9'h05A: dout <= { 10'sd436   , -10'sd269   }; /* W[  90] =  0.8516  -0.5254i */
            9'h05B: dout <= { 10'sd434   , -10'sd271   }; /* W[  91] =  0.8477  -0.5293i */
            9'h05C: dout <= { 10'sd433   , -10'sd274   }; /* W[  92] =  0.8457  -0.5352i */
            9'h05D: dout <= { 10'sd431   , -10'sd277   }; /* W[  93] =  0.8418  -0.5410i */
            9'h05E: dout <= { 10'sd429   , -10'sd279   }; /* W[  94] =  0.8379  -0.5449i */
            9'h05F: dout <= { 10'sd427   , -10'sd282   }; /* W[  95] =  0.8340  -0.5508i */
            9'h060: dout <= { 10'sd426   , -10'sd284   }; /* W[  96] =  0.8320  -0.5547i */
            9'h061: dout <= { 10'sd424   , -10'sd287   }; /* W[  97] =  0.8281  -0.5605i */
            9'h062: dout <= { 10'sd422   , -10'sd290   }; /* W[  98] =  0.8242  -0.5664i */
            9'h063: dout <= { 10'sd420   , -10'sd292   }; /* W[  99] =  0.8203  -0.5703i */
            9'h064: dout <= { 10'sd419   , -10'sd295   }; /* W[ 100] =  0.8184  -0.5762i */
            9'h065: dout <= { 10'sd417   , -10'sd297   }; /* W[ 101] =  0.8145  -0.5801i */
            9'h066: dout <= { 10'sd415   , -10'sd300   }; /* W[ 102] =  0.8105  -0.5859i */
            9'h067: dout <= { 10'sd413   , -10'sd302   }; /* W[ 103] =  0.8066  -0.5898i */
            9'h068: dout <= { 10'sd411   , -10'sd305   }; /* W[ 104] =  0.8027  -0.5957i */
            9'h069: dout <= { 10'sd409   , -10'sd308   }; /* W[ 105] =  0.7988  -0.6016i */
            9'h06A: dout <= { 10'sd407   , -10'sd310   }; /* W[ 106] =  0.7949  -0.6055i */
            9'h06B: dout <= { 10'sd406   , -10'sd313   }; /* W[ 107] =  0.7930  -0.6113i */
            9'h06C: dout <= { 10'sd404   , -10'sd315   }; /* W[ 108] =  0.7891  -0.6152i */
            9'h06D: dout <= { 10'sd402   , -10'sd317   }; /* W[ 109] =  0.7852  -0.6191i */
            9'h06E: dout <= { 10'sd400   , -10'sd320   }; /* W[ 110] =  0.7812  -0.6250i */
            9'h06F: dout <= { 10'sd398   , -10'sd322   }; /* W[ 111] =  0.7773  -0.6289i */
            9'h070: dout <= { 10'sd396   , -10'sd325   }; /* W[ 112] =  0.7734  -0.6348i */
            9'h071: dout <= { 10'sd394   , -10'sd327   }; /* W[ 113] =  0.7695  -0.6387i */
            9'h072: dout <= { 10'sd392   , -10'sd330   }; /* W[ 114] =  0.7656  -0.6445i */
            9'h073: dout <= { 10'sd390   , -10'sd332   }; /* W[ 115] =  0.7617  -0.6484i */
            9'h074: dout <= { 10'sd388   , -10'sd334   }; /* W[ 116] =  0.7578  -0.6523i */
            9'h075: dout <= { 10'sd386   , -10'sd337   }; /* W[ 117] =  0.7539  -0.6582i */
            9'h076: dout <= { 10'sd384   , -10'sd339   }; /* W[ 118] =  0.7500  -0.6621i */
            9'h077: dout <= { 10'sd381   , -10'sd342   }; /* W[ 119] =  0.7441  -0.6680i */
            9'h078: dout <= { 10'sd379   , -10'sd344   }; /* W[ 120] =  0.7402  -0.6719i */
            9'h079: dout <= { 10'sd377   , -10'sd346   }; /* W[ 121] =  0.7363  -0.6758i */
            9'h07A: dout <= { 10'sd375   , -10'sd348   }; /* W[ 122] =  0.7324  -0.6797i */
            9'h07B: dout <= { 10'sd373   , -10'sd351   }; /* W[ 123] =  0.7285  -0.6855i */
            9'h07C: dout <= { 10'sd371   , -10'sd353   }; /* W[ 124] =  0.7246  -0.6895i */
            9'h07D: dout <= { 10'sd369   , -10'sd355   }; /* W[ 125] =  0.7207  -0.6934i */
            9'h07E: dout <= { 10'sd366   , -10'sd358   }; /* W[ 126] =  0.7148  -0.6992i */
            9'h07F: dout <= { 10'sd364   , -10'sd360   }; /* W[ 127] =  0.7109  -0.7031i */
            9'h080: dout <= { 10'sd362   , -10'sd362   }; /* W[ 128] =  0.7070  -0.7070i */
            9'h081: dout <= { 10'sd360   , -10'sd364   }; /* W[ 129] =  0.7031  -0.7109i */
            9'h082: dout <= { 10'sd358   , -10'sd366   }; /* W[ 130] =  0.6992  -0.7148i */
            9'h083: dout <= { 10'sd355   , -10'sd369   }; /* W[ 131] =  0.6934  -0.7207i */
            9'h084: dout <= { 10'sd353   , -10'sd371   }; /* W[ 132] =  0.6895  -0.7246i */
            9'h085: dout <= { 10'sd351   , -10'sd373   }; /* W[ 133] =  0.6855  -0.7285i */
            9'h086: dout <= { 10'sd348   , -10'sd375   }; /* W[ 134] =  0.6797  -0.7324i */
            9'h087: dout <= { 10'sd346   , -10'sd377   }; /* W[ 135] =  0.6758  -0.7363i */
            9'h088: dout <= { 10'sd344   , -10'sd379   }; /* W[ 136] =  0.6719  -0.7402i */
            9'h089: dout <= { 10'sd342   , -10'sd381   }; /* W[ 137] =  0.6680  -0.7441i */
            9'h08A: dout <= { 10'sd339   , -10'sd384   }; /* W[ 138] =  0.6621  -0.7500i */
            9'h08B: dout <= { 10'sd337   , -10'sd386   }; /* W[ 139] =  0.6582  -0.7539i */
            9'h08C: dout <= { 10'sd334   , -10'sd388   }; /* W[ 140] =  0.6523  -0.7578i */
            9'h08D: dout <= { 10'sd332   , -10'sd390   }; /* W[ 141] =  0.6484  -0.7617i */
            9'h08E: dout <= { 10'sd330   , -10'sd392   }; /* W[ 142] =  0.6445  -0.7656i */
            9'h08F: dout <= { 10'sd327   , -10'sd394   }; /* W[ 143] =  0.6387  -0.7695i */
            9'h090: dout <= { 10'sd325   , -10'sd396   }; /* W[ 144] =  0.6348  -0.7734i */
            9'h091: dout <= { 10'sd322   , -10'sd398   }; /* W[ 145] =  0.6289  -0.7773i */
            9'h092: dout <= { 10'sd320   , -10'sd400   }; /* W[ 146] =  0.6250  -0.7812i */
            9'h093: dout <= { 10'sd317   , -10'sd402   }; /* W[ 147] =  0.6191  -0.7852i */
            9'h094: dout <= { 10'sd315   , -10'sd404   }; /* W[ 148] =  0.6152  -0.7891i */
            9'h095: dout <= { 10'sd313   , -10'sd406   }; /* W[ 149] =  0.6113  -0.7930i */
            9'h096: dout <= { 10'sd310   , -10'sd407   }; /* W[ 150] =  0.6055  -0.7949i */
            9'h097: dout <= { 10'sd308   , -10'sd409   }; /* W[ 151] =  0.6016  -0.7988i */
            9'h098: dout <= { 10'sd305   , -10'sd411   }; /* W[ 152] =  0.5957  -0.8027i */
            9'h099: dout <= { 10'sd302   , -10'sd413   }; /* W[ 153] =  0.5898  -0.8066i */
            9'h09A: dout <= { 10'sd300   , -10'sd415   }; /* W[ 154] =  0.5859  -0.8105i */
            9'h09B: dout <= { 10'sd297   , -10'sd417   }; /* W[ 155] =  0.5801  -0.8145i */
            9'h09C: dout <= { 10'sd295   , -10'sd419   }; /* W[ 156] =  0.5762  -0.8184i */
            9'h09D: dout <= { 10'sd292   , -10'sd420   }; /* W[ 157] =  0.5703  -0.8203i */
            9'h09E: dout <= { 10'sd290   , -10'sd422   }; /* W[ 158] =  0.5664  -0.8242i */
            9'h09F: dout <= { 10'sd287   , -10'sd424   }; /* W[ 159] =  0.5605  -0.8281i */
            9'h0A0: dout <= { 10'sd284   , -10'sd426   }; /* W[ 160] =  0.5547  -0.8320i */
            9'h0A1: dout <= { 10'sd282   , -10'sd427   }; /* W[ 161] =  0.5508  -0.8340i */
            9'h0A2: dout <= { 10'sd279   , -10'sd429   }; /* W[ 162] =  0.5449  -0.8379i */
            9'h0A3: dout <= { 10'sd277   , -10'sd431   }; /* W[ 163] =  0.5410  -0.8418i */
            9'h0A4: dout <= { 10'sd274   , -10'sd433   }; /* W[ 164] =  0.5352  -0.8457i */
            9'h0A5: dout <= { 10'sd271   , -10'sd434   }; /* W[ 165] =  0.5293  -0.8477i */
            9'h0A6: dout <= { 10'sd269   , -10'sd436   }; /* W[ 166] =  0.5254  -0.8516i */
            9'h0A7: dout <= { 10'sd266   , -10'sd438   }; /* W[ 167] =  0.5195  -0.8555i */
            9'h0A8: dout <= { 10'sd263   , -10'sd439   }; /* W[ 168] =  0.5137  -0.8574i */
            9'h0A9: dout <= { 10'sd261   , -10'sd441   }; /* W[ 169] =  0.5098  -0.8613i */
            9'h0AA: dout <= { 10'sd258   , -10'sd442   }; /* W[ 170] =  0.5039  -0.8633i */
            9'h0AB: dout <= { 10'sd255   , -10'sd444   }; /* W[ 171] =  0.4980  -0.8672i */
            9'h0AC: dout <= { 10'sd252   , -10'sd445   }; /* W[ 172] =  0.4922  -0.8691i */
            9'h0AD: dout <= { 10'sd250   , -10'sd447   }; /* W[ 173] =  0.4883  -0.8730i */
            9'h0AE: dout <= { 10'sd247   , -10'sd449   }; /* W[ 174] =  0.4824  -0.8770i */
            9'h0AF: dout <= { 10'sd244   , -10'sd450   }; /* W[ 175] =  0.4766  -0.8789i */
            9'h0B0: dout <= { 10'sd241   , -10'sd452   }; /* W[ 176] =  0.4707  -0.8828i */
            9'h0B1: dout <= { 10'sd239   , -10'sd453   }; /* W[ 177] =  0.4668  -0.8848i */
            9'h0B2: dout <= { 10'sd236   , -10'sd454   }; /* W[ 178] =  0.4609  -0.8867i */
            9'h0B3: dout <= { 10'sd233   , -10'sd456   }; /* W[ 179] =  0.4551  -0.8906i */
            9'h0B4: dout <= { 10'sd230   , -10'sd457   }; /* W[ 180] =  0.4492  -0.8926i */
            9'h0B5: dout <= { 10'sd227   , -10'sd459   }; /* W[ 181] =  0.4434  -0.8965i */
            9'h0B6: dout <= { 10'sd225   , -10'sd460   }; /* W[ 182] =  0.4395  -0.8984i */
            9'h0B7: dout <= { 10'sd222   , -10'sd461   }; /* W[ 183] =  0.4336  -0.9004i */
            9'h0B8: dout <= { 10'sd219   , -10'sd463   }; /* W[ 184] =  0.4277  -0.9043i */
            9'h0B9: dout <= { 10'sd216   , -10'sd464   }; /* W[ 185] =  0.4219  -0.9062i */
            9'h0BA: dout <= { 10'sd213   , -10'sd465   }; /* W[ 186] =  0.4160  -0.9082i */
            9'h0BB: dout <= { 10'sd210   , -10'sd467   }; /* W[ 187] =  0.4102  -0.9121i */
            9'h0BC: dout <= { 10'sd207   , -10'sd468   }; /* W[ 188] =  0.4043  -0.9141i */
            9'h0BD: dout <= { 10'sd205   , -10'sd469   }; /* W[ 189] =  0.4004  -0.9160i */
            9'h0BE: dout <= { 10'sd202   , -10'sd471   }; /* W[ 190] =  0.3945  -0.9199i */
            9'h0BF: dout <= { 10'sd199   , -10'sd472   }; /* W[ 191] =  0.3887  -0.9219i */
            9'h0C0: dout <= { 10'sd196   , -10'sd473   }; /* W[ 192] =  0.3828  -0.9238i */
            9'h0C1: dout <= { 10'sd193   , -10'sd474   }; /* W[ 193] =  0.3770  -0.9258i */
            9'h0C2: dout <= { 10'sd190   , -10'sd475   }; /* W[ 194] =  0.3711  -0.9277i */
            9'h0C3: dout <= { 10'sd187   , -10'sd477   }; /* W[ 195] =  0.3652  -0.9316i */
            9'h0C4: dout <= { 10'sd184   , -10'sd478   }; /* W[ 196] =  0.3594  -0.9336i */
            9'h0C5: dout <= { 10'sd181   , -10'sd479   }; /* W[ 197] =  0.3535  -0.9355i */
            9'h0C6: dout <= { 10'sd178   , -10'sd480   }; /* W[ 198] =  0.3477  -0.9375i */
            9'h0C7: dout <= { 10'sd175   , -10'sd481   }; /* W[ 199] =  0.3418  -0.9395i */
            9'h0C8: dout <= { 10'sd172   , -10'sd482   }; /* W[ 200] =  0.3359  -0.9414i */
            9'h0C9: dout <= { 10'sd170   , -10'sd483   }; /* W[ 201] =  0.3320  -0.9434i */
            9'h0CA: dout <= { 10'sd167   , -10'sd484   }; /* W[ 202] =  0.3262  -0.9453i */
            9'h0CB: dout <= { 10'sd164   , -10'sd485   }; /* W[ 203] =  0.3203  -0.9473i */
            9'h0CC: dout <= { 10'sd161   , -10'sd486   }; /* W[ 204] =  0.3145  -0.9492i */
            9'h0CD: dout <= { 10'sd158   , -10'sd487   }; /* W[ 205] =  0.3086  -0.9512i */
            9'h0CE: dout <= { 10'sd155   , -10'sd488   }; /* W[ 206] =  0.3027  -0.9531i */
            9'h0CF: dout <= { 10'sd152   , -10'sd489   }; /* W[ 207] =  0.2969  -0.9551i */
            9'h0D0: dout <= { 10'sd149   , -10'sd490   }; /* W[ 208] =  0.2910  -0.9570i */
            9'h0D1: dout <= { 10'sd146   , -10'sd491   }; /* W[ 209] =  0.2852  -0.9590i */
            9'h0D2: dout <= { 10'sd143   , -10'sd492   }; /* W[ 210] =  0.2793  -0.9609i */
            9'h0D3: dout <= { 10'sd140   , -10'sd493   }; /* W[ 211] =  0.2734  -0.9629i */
            9'h0D4: dout <= { 10'sd137   , -10'sd493   }; /* W[ 212] =  0.2676  -0.9629i */
            9'h0D5: dout <= { 10'sd134   , -10'sd494   }; /* W[ 213] =  0.2617  -0.9648i */
            9'h0D6: dout <= { 10'sd130   , -10'sd495   }; /* W[ 214] =  0.2539  -0.9668i */
            9'h0D7: dout <= { 10'sd127   , -10'sd496   }; /* W[ 215] =  0.2480  -0.9688i */
            9'h0D8: dout <= { 10'sd124   , -10'sd497   }; /* W[ 216] =  0.2422  -0.9707i */
            9'h0D9: dout <= { 10'sd121   , -10'sd497   }; /* W[ 217] =  0.2363  -0.9707i */
            9'h0DA: dout <= { 10'sd118   , -10'sd498   }; /* W[ 218] =  0.2305  -0.9727i */
            9'h0DB: dout <= { 10'sd115   , -10'sd499   }; /* W[ 219] =  0.2246  -0.9746i */
            9'h0DC: dout <= { 10'sd112   , -10'sd500   }; /* W[ 220] =  0.2188  -0.9766i */
            9'h0DD: dout <= { 10'sd109   , -10'sd500   }; /* W[ 221] =  0.2129  -0.9766i */
            9'h0DE: dout <= { 10'sd106   , -10'sd501   }; /* W[ 222] =  0.2070  -0.9785i */
            9'h0DF: dout <= { 10'sd103   , -10'sd502   }; /* W[ 223] =  0.2012  -0.9805i */
            9'h0E0: dout <= { 10'sd100   , -10'sd502   }; /* W[ 224] =  0.1953  -0.9805i */
            9'h0E1: dout <= { 10'sd97    , -10'sd503   }; /* W[ 225] =  0.1895  -0.9824i */
            9'h0E2: dout <= { 10'sd94    , -10'sd503   }; /* W[ 226] =  0.1836  -0.9824i */
            9'h0E3: dout <= { 10'sd91    , -10'sd504   }; /* W[ 227] =  0.1777  -0.9844i */
            9'h0E4: dout <= { 10'sd88    , -10'sd504   }; /* W[ 228] =  0.1719  -0.9844i */
            9'h0E5: dout <= { 10'sd84    , -10'sd505   }; /* W[ 229] =  0.1641  -0.9863i */
            9'h0E6: dout <= { 10'sd81    , -10'sd505   }; /* W[ 230] =  0.1582  -0.9863i */
            9'h0E7: dout <= { 10'sd78    , -10'sd506   }; /* W[ 231] =  0.1523  -0.9883i */
            9'h0E8: dout <= { 10'sd75    , -10'sd506   }; /* W[ 232] =  0.1465  -0.9883i */
            9'h0E9: dout <= { 10'sd72    , -10'sd507   }; /* W[ 233] =  0.1406  -0.9902i */
            9'h0EA: dout <= { 10'sd69    , -10'sd507   }; /* W[ 234] =  0.1348  -0.9902i */
            9'h0EB: dout <= { 10'sd66    , -10'sd508   }; /* W[ 235] =  0.1289  -0.9922i */
            9'h0EC: dout <= { 10'sd63    , -10'sd508   }; /* W[ 236] =  0.1230  -0.9922i */
            9'h0ED: dout <= { 10'sd60    , -10'sd509   }; /* W[ 237] =  0.1172  -0.9941i */
            9'h0EE: dout <= { 10'sd56    , -10'sd509   }; /* W[ 238] =  0.1094  -0.9941i */
            9'h0EF: dout <= { 10'sd53    , -10'sd509   }; /* W[ 239] =  0.1035  -0.9941i */
            9'h0F0: dout <= { 10'sd50    , -10'sd510   }; /* W[ 240] =  0.0977  -0.9961i */
            9'h0F1: dout <= { 10'sd47    , -10'sd510   }; /* W[ 241] =  0.0918  -0.9961i */
            9'h0F2: dout <= { 10'sd44    , -10'sd510   }; /* W[ 242] =  0.0859  -0.9961i */
            9'h0F3: dout <= { 10'sd41    , -10'sd510   }; /* W[ 243] =  0.0801  -0.9961i */
            9'h0F4: dout <= { 10'sd38    , -10'sd511   }; /* W[ 244] =  0.0742  -0.9980i */
            9'h0F5: dout <= { 10'sd35    , -10'sd511   }; /* W[ 245] =  0.0684  -0.9980i */
            9'h0F6: dout <= { 10'sd31    , -10'sd511   }; /* W[ 246] =  0.0605  -0.9980i */
            9'h0F7: dout <= { 10'sd28    , -10'sd511   }; /* W[ 247] =  0.0547  -0.9980i */
            9'h0F8: dout <= { 10'sd25    , -10'sd511   }; /* W[ 248] =  0.0488  -0.9980i */
            9'h0F9: dout <= { 10'sd22    , -10'sd512   }; /* W[ 249] =  0.0430  -1.0000i */
            9'h0FA: dout <= { 10'sd19    , -10'sd512   }; /* W[ 250] =  0.0371  -1.0000i */
            9'h0FB: dout <= { 10'sd16    , -10'sd512   }; /* W[ 251] =  0.0312  -1.0000i */
            9'h0FC: dout <= { 10'sd13    , -10'sd512   }; /* W[ 252] =  0.0254  -1.0000i */
            9'h0FD: dout <= { 10'sd9     , -10'sd512   }; /* W[ 253] =  0.0176  -1.0000i */
            9'h0FE: dout <= { 10'sd6     , -10'sd512   }; /* W[ 254] =  0.0117  -1.0000i */
            9'h0FF: dout <= { 10'sd3     , -10'sd512   }; /* W[ 255] =  0.0059  -1.0000i */
            9'h100: dout <= { 10'sd0     , -10'sd512   }; /* W[ 256] =  0.0000  -1.0000i */
            9'h101: dout <= {-10'sd3     , -10'sd512   }; /* W[ 257] = -0.0059  -1.0000i */
            9'h102: dout <= {-10'sd6     , -10'sd512   }; /* W[ 258] = -0.0117  -1.0000i */
            9'h103: dout <= {-10'sd9     , -10'sd512   }; /* W[ 259] = -0.0176  -1.0000i */
            9'h104: dout <= {-10'sd13    , -10'sd512   }; /* W[ 260] = -0.0254  -1.0000i */
            9'h105: dout <= {-10'sd16    , -10'sd512   }; /* W[ 261] = -0.0312  -1.0000i */
            9'h106: dout <= {-10'sd19    , -10'sd512   }; /* W[ 262] = -0.0371  -1.0000i */
            9'h107: dout <= {-10'sd22    , -10'sd512   }; /* W[ 263] = -0.0430  -1.0000i */
            9'h108: dout <= {-10'sd25    , -10'sd511   }; /* W[ 264] = -0.0488  -0.9980i */
            9'h109: dout <= {-10'sd28    , -10'sd511   }; /* W[ 265] = -0.0547  -0.9980i */
            9'h10A: dout <= {-10'sd31    , -10'sd511   }; /* W[ 266] = -0.0605  -0.9980i */
            9'h10B: dout <= {-10'sd35    , -10'sd511   }; /* W[ 267] = -0.0684  -0.9980i */
            9'h10C: dout <= {-10'sd38    , -10'sd511   }; /* W[ 268] = -0.0742  -0.9980i */
            9'h10D: dout <= {-10'sd41    , -10'sd510   }; /* W[ 269] = -0.0801  -0.9961i */
            9'h10E: dout <= {-10'sd44    , -10'sd510   }; /* W[ 270] = -0.0859  -0.9961i */
            9'h10F: dout <= {-10'sd47    , -10'sd510   }; /* W[ 271] = -0.0918  -0.9961i */
            9'h110: dout <= {-10'sd50    , -10'sd510   }; /* W[ 272] = -0.0977  -0.9961i */
            9'h111: dout <= {-10'sd53    , -10'sd509   }; /* W[ 273] = -0.1035  -0.9941i */
            9'h112: dout <= {-10'sd56    , -10'sd509   }; /* W[ 274] = -0.1094  -0.9941i */
            9'h113: dout <= {-10'sd60    , -10'sd509   }; /* W[ 275] = -0.1172  -0.9941i */
            9'h114: dout <= {-10'sd63    , -10'sd508   }; /* W[ 276] = -0.1230  -0.9922i */
            9'h115: dout <= {-10'sd66    , -10'sd508   }; /* W[ 277] = -0.1289  -0.9922i */
            9'h116: dout <= {-10'sd69    , -10'sd507   }; /* W[ 278] = -0.1348  -0.9902i */
            9'h117: dout <= {-10'sd72    , -10'sd507   }; /* W[ 279] = -0.1406  -0.9902i */
            9'h118: dout <= {-10'sd75    , -10'sd506   }; /* W[ 280] = -0.1465  -0.9883i */
            9'h119: dout <= {-10'sd78    , -10'sd506   }; /* W[ 281] = -0.1523  -0.9883i */
            9'h11A: dout <= {-10'sd81    , -10'sd505   }; /* W[ 282] = -0.1582  -0.9863i */
            9'h11B: dout <= {-10'sd84    , -10'sd505   }; /* W[ 283] = -0.1641  -0.9863i */
            9'h11C: dout <= {-10'sd88    , -10'sd504   }; /* W[ 284] = -0.1719  -0.9844i */
            9'h11D: dout <= {-10'sd91    , -10'sd504   }; /* W[ 285] = -0.1777  -0.9844i */
            9'h11E: dout <= {-10'sd94    , -10'sd503   }; /* W[ 286] = -0.1836  -0.9824i */
            9'h11F: dout <= {-10'sd97    , -10'sd503   }; /* W[ 287] = -0.1895  -0.9824i */
            9'h120: dout <= {-10'sd100   , -10'sd502   }; /* W[ 288] = -0.1953  -0.9805i */
            9'h121: dout <= {-10'sd103   , -10'sd502   }; /* W[ 289] = -0.2012  -0.9805i */
            9'h122: dout <= {-10'sd106   , -10'sd501   }; /* W[ 290] = -0.2070  -0.9785i */
            9'h123: dout <= {-10'sd109   , -10'sd500   }; /* W[ 291] = -0.2129  -0.9766i */
            9'h124: dout <= {-10'sd112   , -10'sd500   }; /* W[ 292] = -0.2188  -0.9766i */
            9'h125: dout <= {-10'sd115   , -10'sd499   }; /* W[ 293] = -0.2246  -0.9746i */
            9'h126: dout <= {-10'sd118   , -10'sd498   }; /* W[ 294] = -0.2305  -0.9727i */
            9'h127: dout <= {-10'sd121   , -10'sd497   }; /* W[ 295] = -0.2363  -0.9707i */
            9'h128: dout <= {-10'sd124   , -10'sd497   }; /* W[ 296] = -0.2422  -0.9707i */
            9'h129: dout <= {-10'sd127   , -10'sd496   }; /* W[ 297] = -0.2480  -0.9688i */
            9'h12A: dout <= {-10'sd130   , -10'sd495   }; /* W[ 298] = -0.2539  -0.9668i */
            9'h12B: dout <= {-10'sd134   , -10'sd494   }; /* W[ 299] = -0.2617  -0.9648i */
            9'h12C: dout <= {-10'sd137   , -10'sd493   }; /* W[ 300] = -0.2676  -0.9629i */
            9'h12D: dout <= {-10'sd140   , -10'sd493   }; /* W[ 301] = -0.2734  -0.9629i */
            9'h12E: dout <= {-10'sd143   , -10'sd492   }; /* W[ 302] = -0.2793  -0.9609i */
            9'h12F: dout <= {-10'sd146   , -10'sd491   }; /* W[ 303] = -0.2852  -0.9590i */
            9'h130: dout <= {-10'sd149   , -10'sd490   }; /* W[ 304] = -0.2910  -0.9570i */
            9'h131: dout <= {-10'sd152   , -10'sd489   }; /* W[ 305] = -0.2969  -0.9551i */
            9'h132: dout <= {-10'sd155   , -10'sd488   }; /* W[ 306] = -0.3027  -0.9531i */
            9'h133: dout <= {-10'sd158   , -10'sd487   }; /* W[ 307] = -0.3086  -0.9512i */
            9'h134: dout <= {-10'sd161   , -10'sd486   }; /* W[ 308] = -0.3145  -0.9492i */
            9'h135: dout <= {-10'sd164   , -10'sd485   }; /* W[ 309] = -0.3203  -0.9473i */
            9'h136: dout <= {-10'sd167   , -10'sd484   }; /* W[ 310] = -0.3262  -0.9453i */
            9'h137: dout <= {-10'sd170   , -10'sd483   }; /* W[ 311] = -0.3320  -0.9434i */
            9'h138: dout <= {-10'sd172   , -10'sd482   }; /* W[ 312] = -0.3359  -0.9414i */
            9'h139: dout <= {-10'sd175   , -10'sd481   }; /* W[ 313] = -0.3418  -0.9395i */
            9'h13A: dout <= {-10'sd178   , -10'sd480   }; /* W[ 314] = -0.3477  -0.9375i */
            9'h13B: dout <= {-10'sd181   , -10'sd479   }; /* W[ 315] = -0.3535  -0.9355i */
            9'h13C: dout <= {-10'sd184   , -10'sd478   }; /* W[ 316] = -0.3594  -0.9336i */
            9'h13D: dout <= {-10'sd187   , -10'sd477   }; /* W[ 317] = -0.3652  -0.9316i */
            9'h13E: dout <= {-10'sd190   , -10'sd475   }; /* W[ 318] = -0.3711  -0.9277i */
            9'h13F: dout <= {-10'sd193   , -10'sd474   }; /* W[ 319] = -0.3770  -0.9258i */
            9'h140: dout <= {-10'sd196   , -10'sd473   }; /* W[ 320] = -0.3828  -0.9238i */
            9'h141: dout <= {-10'sd199   , -10'sd472   }; /* W[ 321] = -0.3887  -0.9219i */
            9'h142: dout <= {-10'sd202   , -10'sd471   }; /* W[ 322] = -0.3945  -0.9199i */
            9'h143: dout <= {-10'sd205   , -10'sd469   }; /* W[ 323] = -0.4004  -0.9160i */
            9'h144: dout <= {-10'sd207   , -10'sd468   }; /* W[ 324] = -0.4043  -0.9141i */
            9'h145: dout <= {-10'sd210   , -10'sd467   }; /* W[ 325] = -0.4102  -0.9121i */
            9'h146: dout <= {-10'sd213   , -10'sd465   }; /* W[ 326] = -0.4160  -0.9082i */
            9'h147: dout <= {-10'sd216   , -10'sd464   }; /* W[ 327] = -0.4219  -0.9062i */
            9'h148: dout <= {-10'sd219   , -10'sd463   }; /* W[ 328] = -0.4277  -0.9043i */
            9'h149: dout <= {-10'sd222   , -10'sd461   }; /* W[ 329] = -0.4336  -0.9004i */
            9'h14A: dout <= {-10'sd225   , -10'sd460   }; /* W[ 330] = -0.4395  -0.8984i */
            9'h14B: dout <= {-10'sd227   , -10'sd459   }; /* W[ 331] = -0.4434  -0.8965i */
            9'h14C: dout <= {-10'sd230   , -10'sd457   }; /* W[ 332] = -0.4492  -0.8926i */
            9'h14D: dout <= {-10'sd233   , -10'sd456   }; /* W[ 333] = -0.4551  -0.8906i */
            9'h14E: dout <= {-10'sd236   , -10'sd454   }; /* W[ 334] = -0.4609  -0.8867i */
            9'h14F: dout <= {-10'sd239   , -10'sd453   }; /* W[ 335] = -0.4668  -0.8848i */
            9'h150: dout <= {-10'sd241   , -10'sd452   }; /* W[ 336] = -0.4707  -0.8828i */
            9'h151: dout <= {-10'sd244   , -10'sd450   }; /* W[ 337] = -0.4766  -0.8789i */
            9'h152: dout <= {-10'sd247   , -10'sd449   }; /* W[ 338] = -0.4824  -0.8770i */
            9'h153: dout <= {-10'sd250   , -10'sd447   }; /* W[ 339] = -0.4883  -0.8730i */
            9'h154: dout <= {-10'sd252   , -10'sd445   }; /* W[ 340] = -0.4922  -0.8691i */
            9'h155: dout <= {-10'sd255   , -10'sd444   }; /* W[ 341] = -0.4980  -0.8672i */
            9'h156: dout <= {-10'sd258   , -10'sd442   }; /* W[ 342] = -0.5039  -0.8633i */
            9'h157: dout <= {-10'sd261   , -10'sd441   }; /* W[ 343] = -0.5098  -0.8613i */
            9'h158: dout <= {-10'sd263   , -10'sd439   }; /* W[ 344] = -0.5137  -0.8574i */
            9'h159: dout <= {-10'sd266   , -10'sd438   }; /* W[ 345] = -0.5195  -0.8555i */
            9'h15A: dout <= {-10'sd269   , -10'sd436   }; /* W[ 346] = -0.5254  -0.8516i */
            9'h15B: dout <= {-10'sd271   , -10'sd434   }; /* W[ 347] = -0.5293  -0.8477i */
            9'h15C: dout <= {-10'sd274   , -10'sd433   }; /* W[ 348] = -0.5352  -0.8457i */
            9'h15D: dout <= {-10'sd277   , -10'sd431   }; /* W[ 349] = -0.5410  -0.8418i */
            9'h15E: dout <= {-10'sd279   , -10'sd429   }; /* W[ 350] = -0.5449  -0.8379i */
            9'h15F: dout <= {-10'sd282   , -10'sd427   }; /* W[ 351] = -0.5508  -0.8340i */
            9'h160: dout <= {-10'sd284   , -10'sd426   }; /* W[ 352] = -0.5547  -0.8320i */
            9'h161: dout <= {-10'sd287   , -10'sd424   }; /* W[ 353] = -0.5605  -0.8281i */
            9'h162: dout <= {-10'sd290   , -10'sd422   }; /* W[ 354] = -0.5664  -0.8242i */
            9'h163: dout <= {-10'sd292   , -10'sd420   }; /* W[ 355] = -0.5703  -0.8203i */
            9'h164: dout <= {-10'sd295   , -10'sd419   }; /* W[ 356] = -0.5762  -0.8184i */
            9'h165: dout <= {-10'sd297   , -10'sd417   }; /* W[ 357] = -0.5801  -0.8145i */
            9'h166: dout <= {-10'sd300   , -10'sd415   }; /* W[ 358] = -0.5859  -0.8105i */
            9'h167: dout <= {-10'sd302   , -10'sd413   }; /* W[ 359] = -0.5898  -0.8066i */
            9'h168: dout <= {-10'sd305   , -10'sd411   }; /* W[ 360] = -0.5957  -0.8027i */
            9'h169: dout <= {-10'sd308   , -10'sd409   }; /* W[ 361] = -0.6016  -0.7988i */
            9'h16A: dout <= {-10'sd310   , -10'sd407   }; /* W[ 362] = -0.6055  -0.7949i */
            9'h16B: dout <= {-10'sd313   , -10'sd406   }; /* W[ 363] = -0.6113  -0.7930i */
            9'h16C: dout <= {-10'sd315   , -10'sd404   }; /* W[ 364] = -0.6152  -0.7891i */
            9'h16D: dout <= {-10'sd317   , -10'sd402   }; /* W[ 365] = -0.6191  -0.7852i */
            9'h16E: dout <= {-10'sd320   , -10'sd400   }; /* W[ 366] = -0.6250  -0.7812i */
            9'h16F: dout <= {-10'sd322   , -10'sd398   }; /* W[ 367] = -0.6289  -0.7773i */
            9'h170: dout <= {-10'sd325   , -10'sd396   }; /* W[ 368] = -0.6348  -0.7734i */
            9'h171: dout <= {-10'sd327   , -10'sd394   }; /* W[ 369] = -0.6387  -0.7695i */
            9'h172: dout <= {-10'sd330   , -10'sd392   }; /* W[ 370] = -0.6445  -0.7656i */
            9'h173: dout <= {-10'sd332   , -10'sd390   }; /* W[ 371] = -0.6484  -0.7617i */
            9'h174: dout <= {-10'sd334   , -10'sd388   }; /* W[ 372] = -0.6523  -0.7578i */
            9'h175: dout <= {-10'sd337   , -10'sd386   }; /* W[ 373] = -0.6582  -0.7539i */
            9'h176: dout <= {-10'sd339   , -10'sd384   }; /* W[ 374] = -0.6621  -0.7500i */
            9'h177: dout <= {-10'sd342   , -10'sd381   }; /* W[ 375] = -0.6680  -0.7441i */
            9'h178: dout <= {-10'sd344   , -10'sd379   }; /* W[ 376] = -0.6719  -0.7402i */
            9'h179: dout <= {-10'sd346   , -10'sd377   }; /* W[ 377] = -0.6758  -0.7363i */
            9'h17A: dout <= {-10'sd348   , -10'sd375   }; /* W[ 378] = -0.6797  -0.7324i */
            9'h17B: dout <= {-10'sd351   , -10'sd373   }; /* W[ 379] = -0.6855  -0.7285i */
            9'h17C: dout <= {-10'sd353   , -10'sd371   }; /* W[ 380] = -0.6895  -0.7246i */
            9'h17D: dout <= {-10'sd355   , -10'sd369   }; /* W[ 381] = -0.6934  -0.7207i */
            9'h17E: dout <= {-10'sd358   , -10'sd366   }; /* W[ 382] = -0.6992  -0.7148i */
            9'h17F: dout <= {-10'sd360   , -10'sd364   }; /* W[ 383] = -0.7031  -0.7109i */
            9'h180: dout <= {-10'sd362   , -10'sd362   }; /* W[ 384] = -0.7070  -0.7070i */
            9'h181: dout <= {-10'sd364   , -10'sd360   }; /* W[ 385] = -0.7109  -0.7031i */
            9'h182: dout <= {-10'sd366   , -10'sd358   }; /* W[ 386] = -0.7148  -0.6992i */
            9'h183: dout <= {-10'sd369   , -10'sd355   }; /* W[ 387] = -0.7207  -0.6934i */
            9'h184: dout <= {-10'sd371   , -10'sd353   }; /* W[ 388] = -0.7246  -0.6895i */
            9'h185: dout <= {-10'sd373   , -10'sd351   }; /* W[ 389] = -0.7285  -0.6855i */
            9'h186: dout <= {-10'sd375   , -10'sd348   }; /* W[ 390] = -0.7324  -0.6797i */
            9'h187: dout <= {-10'sd377   , -10'sd346   }; /* W[ 391] = -0.7363  -0.6758i */
            9'h188: dout <= {-10'sd379   , -10'sd344   }; /* W[ 392] = -0.7402  -0.6719i */
            9'h189: dout <= {-10'sd381   , -10'sd342   }; /* W[ 393] = -0.7441  -0.6680i */
            9'h18A: dout <= {-10'sd384   , -10'sd339   }; /* W[ 394] = -0.7500  -0.6621i */
            9'h18B: dout <= {-10'sd386   , -10'sd337   }; /* W[ 395] = -0.7539  -0.6582i */
            9'h18C: dout <= {-10'sd388   , -10'sd334   }; /* W[ 396] = -0.7578  -0.6523i */
            9'h18D: dout <= {-10'sd390   , -10'sd332   }; /* W[ 397] = -0.7617  -0.6484i */
            9'h18E: dout <= {-10'sd392   , -10'sd330   }; /* W[ 398] = -0.7656  -0.6445i */
            9'h18F: dout <= {-10'sd394   , -10'sd327   }; /* W[ 399] = -0.7695  -0.6387i */
            9'h190: dout <= {-10'sd396   , -10'sd325   }; /* W[ 400] = -0.7734  -0.6348i */
            9'h191: dout <= {-10'sd398   , -10'sd322   }; /* W[ 401] = -0.7773  -0.6289i */
            9'h192: dout <= {-10'sd400   , -10'sd320   }; /* W[ 402] = -0.7812  -0.6250i */
            9'h193: dout <= {-10'sd402   , -10'sd317   }; /* W[ 403] = -0.7852  -0.6191i */
            9'h194: dout <= {-10'sd404   , -10'sd315   }; /* W[ 404] = -0.7891  -0.6152i */
            9'h195: dout <= {-10'sd406   , -10'sd313   }; /* W[ 405] = -0.7930  -0.6113i */
            9'h196: dout <= {-10'sd407   , -10'sd310   }; /* W[ 406] = -0.7949  -0.6055i */
            9'h197: dout <= {-10'sd409   , -10'sd308   }; /* W[ 407] = -0.7988  -0.6016i */
            9'h198: dout <= {-10'sd411   , -10'sd305   }; /* W[ 408] = -0.8027  -0.5957i */
            9'h199: dout <= {-10'sd413   , -10'sd302   }; /* W[ 409] = -0.8066  -0.5898i */
            9'h19A: dout <= {-10'sd415   , -10'sd300   }; /* W[ 410] = -0.8105  -0.5859i */
            9'h19B: dout <= {-10'sd417   , -10'sd297   }; /* W[ 411] = -0.8145  -0.5801i */
            9'h19C: dout <= {-10'sd419   , -10'sd295   }; /* W[ 412] = -0.8184  -0.5762i */
            9'h19D: dout <= {-10'sd420   , -10'sd292   }; /* W[ 413] = -0.8203  -0.5703i */
            9'h19E: dout <= {-10'sd422   , -10'sd290   }; /* W[ 414] = -0.8242  -0.5664i */
            9'h19F: dout <= {-10'sd424   , -10'sd287   }; /* W[ 415] = -0.8281  -0.5605i */
            9'h1A0: dout <= {-10'sd426   , -10'sd284   }; /* W[ 416] = -0.8320  -0.5547i */
            9'h1A1: dout <= {-10'sd427   , -10'sd282   }; /* W[ 417] = -0.8340  -0.5508i */
            9'h1A2: dout <= {-10'sd429   , -10'sd279   }; /* W[ 418] = -0.8379  -0.5449i */
            9'h1A3: dout <= {-10'sd431   , -10'sd277   }; /* W[ 419] = -0.8418  -0.5410i */
            9'h1A4: dout <= {-10'sd433   , -10'sd274   }; /* W[ 420] = -0.8457  -0.5352i */
            9'h1A5: dout <= {-10'sd434   , -10'sd271   }; /* W[ 421] = -0.8477  -0.5293i */
            9'h1A6: dout <= {-10'sd436   , -10'sd269   }; /* W[ 422] = -0.8516  -0.5254i */
            9'h1A7: dout <= {-10'sd438   , -10'sd266   }; /* W[ 423] = -0.8555  -0.5195i */
            9'h1A8: dout <= {-10'sd439   , -10'sd263   }; /* W[ 424] = -0.8574  -0.5137i */
            9'h1A9: dout <= {-10'sd441   , -10'sd261   }; /* W[ 425] = -0.8613  -0.5098i */
            9'h1AA: dout <= {-10'sd442   , -10'sd258   }; /* W[ 426] = -0.8633  -0.5039i */
            9'h1AB: dout <= {-10'sd444   , -10'sd255   }; /* W[ 427] = -0.8672  -0.4980i */
            9'h1AC: dout <= {-10'sd445   , -10'sd252   }; /* W[ 428] = -0.8691  -0.4922i */
            9'h1AD: dout <= {-10'sd447   , -10'sd250   }; /* W[ 429] = -0.8730  -0.4883i */
            9'h1AE: dout <= {-10'sd449   , -10'sd247   }; /* W[ 430] = -0.8770  -0.4824i */
            9'h1AF: dout <= {-10'sd450   , -10'sd244   }; /* W[ 431] = -0.8789  -0.4766i */
            9'h1B0: dout <= {-10'sd452   , -10'sd241   }; /* W[ 432] = -0.8828  -0.4707i */
            9'h1B1: dout <= {-10'sd453   , -10'sd239   }; /* W[ 433] = -0.8848  -0.4668i */
            9'h1B2: dout <= {-10'sd454   , -10'sd236   }; /* W[ 434] = -0.8867  -0.4609i */
            9'h1B3: dout <= {-10'sd456   , -10'sd233   }; /* W[ 435] = -0.8906  -0.4551i */
            9'h1B4: dout <= {-10'sd457   , -10'sd230   }; /* W[ 436] = -0.8926  -0.4492i */
            9'h1B5: dout <= {-10'sd459   , -10'sd227   }; /* W[ 437] = -0.8965  -0.4434i */
            9'h1B6: dout <= {-10'sd460   , -10'sd225   }; /* W[ 438] = -0.8984  -0.4395i */
            9'h1B7: dout <= {-10'sd461   , -10'sd222   }; /* W[ 439] = -0.9004  -0.4336i */
            9'h1B8: dout <= {-10'sd463   , -10'sd219   }; /* W[ 440] = -0.9043  -0.4277i */
            9'h1B9: dout <= {-10'sd464   , -10'sd216   }; /* W[ 441] = -0.9062  -0.4219i */
            9'h1BA: dout <= {-10'sd465   , -10'sd213   }; /* W[ 442] = -0.9082  -0.4160i */
            9'h1BB: dout <= {-10'sd467   , -10'sd210   }; /* W[ 443] = -0.9121  -0.4102i */
            9'h1BC: dout <= {-10'sd468   , -10'sd207   }; /* W[ 444] = -0.9141  -0.4043i */
            9'h1BD: dout <= {-10'sd469   , -10'sd205   }; /* W[ 445] = -0.9160  -0.4004i */
            9'h1BE: dout <= {-10'sd471   , -10'sd202   }; /* W[ 446] = -0.9199  -0.3945i */
            9'h1BF: dout <= {-10'sd472   , -10'sd199   }; /* W[ 447] = -0.9219  -0.3887i */
            9'h1C0: dout <= {-10'sd473   , -10'sd196   }; /* W[ 448] = -0.9238  -0.3828i */
            9'h1C1: dout <= {-10'sd474   , -10'sd193   }; /* W[ 449] = -0.9258  -0.3770i */
            9'h1C2: dout <= {-10'sd475   , -10'sd190   }; /* W[ 450] = -0.9277  -0.3711i */
            9'h1C3: dout <= {-10'sd477   , -10'sd187   }; /* W[ 451] = -0.9316  -0.3652i */
            9'h1C4: dout <= {-10'sd478   , -10'sd184   }; /* W[ 452] = -0.9336  -0.3594i */
            9'h1C5: dout <= {-10'sd479   , -10'sd181   }; /* W[ 453] = -0.9355  -0.3535i */
            9'h1C6: dout <= {-10'sd480   , -10'sd178   }; /* W[ 454] = -0.9375  -0.3477i */
            9'h1C7: dout <= {-10'sd481   , -10'sd175   }; /* W[ 455] = -0.9395  -0.3418i */
            9'h1C8: dout <= {-10'sd482   , -10'sd172   }; /* W[ 456] = -0.9414  -0.3359i */
            9'h1C9: dout <= {-10'sd483   , -10'sd170   }; /* W[ 457] = -0.9434  -0.3320i */
            9'h1CA: dout <= {-10'sd484   , -10'sd167   }; /* W[ 458] = -0.9453  -0.3262i */
            9'h1CB: dout <= {-10'sd485   , -10'sd164   }; /* W[ 459] = -0.9473  -0.3203i */
            9'h1CC: dout <= {-10'sd486   , -10'sd161   }; /* W[ 460] = -0.9492  -0.3145i */
            9'h1CD: dout <= {-10'sd487   , -10'sd158   }; /* W[ 461] = -0.9512  -0.3086i */
            9'h1CE: dout <= {-10'sd488   , -10'sd155   }; /* W[ 462] = -0.9531  -0.3027i */
            9'h1CF: dout <= {-10'sd489   , -10'sd152   }; /* W[ 463] = -0.9551  -0.2969i */
            9'h1D0: dout <= {-10'sd490   , -10'sd149   }; /* W[ 464] = -0.9570  -0.2910i */
            9'h1D1: dout <= {-10'sd491   , -10'sd146   }; /* W[ 465] = -0.9590  -0.2852i */
            9'h1D2: dout <= {-10'sd492   , -10'sd143   }; /* W[ 466] = -0.9609  -0.2793i */
            9'h1D3: dout <= {-10'sd493   , -10'sd140   }; /* W[ 467] = -0.9629  -0.2734i */
            9'h1D4: dout <= {-10'sd493   , -10'sd137   }; /* W[ 468] = -0.9629  -0.2676i */
            9'h1D5: dout <= {-10'sd494   , -10'sd134   }; /* W[ 469] = -0.9648  -0.2617i */
            9'h1D6: dout <= {-10'sd495   , -10'sd130   }; /* W[ 470] = -0.9668  -0.2539i */
            9'h1D7: dout <= {-10'sd496   , -10'sd127   }; /* W[ 471] = -0.9688  -0.2480i */
            9'h1D8: dout <= {-10'sd497   , -10'sd124   }; /* W[ 472] = -0.9707  -0.2422i */
            9'h1D9: dout <= {-10'sd497   , -10'sd121   }; /* W[ 473] = -0.9707  -0.2363i */
            9'h1DA: dout <= {-10'sd498   , -10'sd118   }; /* W[ 474] = -0.9727  -0.2305i */
            9'h1DB: dout <= {-10'sd499   , -10'sd115   }; /* W[ 475] = -0.9746  -0.2246i */
            9'h1DC: dout <= {-10'sd500   , -10'sd112   }; /* W[ 476] = -0.9766  -0.2188i */
            9'h1DD: dout <= {-10'sd500   , -10'sd109   }; /* W[ 477] = -0.9766  -0.2129i */
            9'h1DE: dout <= {-10'sd501   , -10'sd106   }; /* W[ 478] = -0.9785  -0.2070i */
            9'h1DF: dout <= {-10'sd502   , -10'sd103   }; /* W[ 479] = -0.9805  -0.2012i */
            9'h1E0: dout <= {-10'sd502   , -10'sd100   }; /* W[ 480] = -0.9805  -0.1953i */
            9'h1E1: dout <= {-10'sd503   , -10'sd97    }; /* W[ 481] = -0.9824  -0.1895i */
            9'h1E2: dout <= {-10'sd503   , -10'sd94    }; /* W[ 482] = -0.9824  -0.1836i */
            9'h1E3: dout <= {-10'sd504   , -10'sd91    }; /* W[ 483] = -0.9844  -0.1777i */
            9'h1E4: dout <= {-10'sd504   , -10'sd88    }; /* W[ 484] = -0.9844  -0.1719i */
            9'h1E5: dout <= {-10'sd505   , -10'sd84    }; /* W[ 485] = -0.9863  -0.1641i */
            9'h1E6: dout <= {-10'sd505   , -10'sd81    }; /* W[ 486] = -0.9863  -0.1582i */
            9'h1E7: dout <= {-10'sd506   , -10'sd78    }; /* W[ 487] = -0.9883  -0.1523i */
            9'h1E8: dout <= {-10'sd506   , -10'sd75    }; /* W[ 488] = -0.9883  -0.1465i */
            9'h1E9: dout <= {-10'sd507   , -10'sd72    }; /* W[ 489] = -0.9902  -0.1406i */
            9'h1EA: dout <= {-10'sd507   , -10'sd69    }; /* W[ 490] = -0.9902  -0.1348i */
            9'h1EB: dout <= {-10'sd508   , -10'sd66    }; /* W[ 491] = -0.9922  -0.1289i */
            9'h1EC: dout <= {-10'sd508   , -10'sd63    }; /* W[ 492] = -0.9922  -0.1230i */
            9'h1ED: dout <= {-10'sd509   , -10'sd60    }; /* W[ 493] = -0.9941  -0.1172i */
            9'h1EE: dout <= {-10'sd509   , -10'sd56    }; /* W[ 494] = -0.9941  -0.1094i */
            9'h1EF: dout <= {-10'sd509   , -10'sd53    }; /* W[ 495] = -0.9941  -0.1035i */
            9'h1F0: dout <= {-10'sd510   , -10'sd50    }; /* W[ 496] = -0.9961  -0.0977i */
            9'h1F1: dout <= {-10'sd510   , -10'sd47    }; /* W[ 497] = -0.9961  -0.0918i */
            9'h1F2: dout <= {-10'sd510   , -10'sd44    }; /* W[ 498] = -0.9961  -0.0859i */
            9'h1F3: dout <= {-10'sd510   , -10'sd41    }; /* W[ 499] = -0.9961  -0.0801i */
            9'h1F4: dout <= {-10'sd511   , -10'sd38    }; /* W[ 500] = -0.9980  -0.0742i */
            9'h1F5: dout <= {-10'sd511   , -10'sd35    }; /* W[ 501] = -0.9980  -0.0684i */
            9'h1F6: dout <= {-10'sd511   , -10'sd31    }; /* W[ 502] = -0.9980  -0.0605i */
            9'h1F7: dout <= {-10'sd511   , -10'sd28    }; /* W[ 503] = -0.9980  -0.0547i */
            9'h1F8: dout <= {-10'sd511   , -10'sd25    }; /* W[ 504] = -0.9980  -0.0488i */
            9'h1F9: dout <= {-10'sd512   , -10'sd22    }; /* W[ 505] = -1.0000  -0.0430i */
            9'h1FA: dout <= {-10'sd512   , -10'sd19    }; /* W[ 506] = -1.0000  -0.0371i */
            9'h1FB: dout <= {-10'sd512   , -10'sd16    }; /* W[ 507] = -1.0000  -0.0312i */
            9'h1FC: dout <= {-10'sd512   , -10'sd13    }; /* W[ 508] = -1.0000  -0.0254i */
            9'h1FD: dout <= {-10'sd512   , -10'sd9     }; /* W[ 509] = -1.0000  -0.0176i */
            9'h1FE: dout <= {-10'sd512   , -10'sd6     }; /* W[ 510] = -1.0000  -0.0117i */
            9'h1FF: dout <= {-10'sd512   , -10'sd3     }; /* W[ 511] = -1.0000  -0.0059i */
            default:
              begin
                dout <= 20'd0;
              end
         endcase
      end
  end
endmodule

/** @} */ /* End of addtogroup ModMiscIpDspFftR2Rom */
/* END OF FILE */
